#
# spec file for package grub2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# needssslcertforbuild


Name:           grub2
%ifarch x86_64 ppc64
BuildRequires:  gcc-32bit
BuildRequires:  glibc-32bit
BuildRequires:  glibc-devel-32bit
%else
BuildRequires:  gcc
BuildRequires:  glibc-devel
%endif
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  dejavu-fonts
BuildRequires:  device-mapper-devel
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  freetype2-devel
BuildRequires:  fuse-devel
%if 0%{?suse_version} >= 1140
BuildRequires:  gnu-unifont
%endif
BuildRequires:  help2man
BuildRequires:  xz
%if 0%{?suse_version} >= 1210
BuildRequires:  makeinfo
%else
BuildRequires:  texinfo
%endif
BuildRequires:  python
BuildRequires:  xz-devel
%ifarch x86_64
%if 0%{?suse_version} >= 1230 || 0%{?suse_version} == 1110
BuildRequires:  openssl >= 0.9.8
BuildRequires:  pesign-obs-integration
%endif
%endif
%if 0%{?suse_version} >= 1210
BuildRequires:  systemd
%define has_systemd 1
%endif

# Modules code is dynamically loaded and collected from a _fixed_ path.
%define _libdir %{_exec_prefix}/lib

# Build grub2-emu everywhere (it may be "required" by 'grub2-once')
%define emu 1

%ifarch ppc ppc64 ppc64le
%define grubcpu powerpc
%define platform ieee1275
# emu does not build here yet... :-(
%define emu 0
%endif

%ifarch %{ix86} x86_64
%define grubcpu i386
%define platform pc
%endif

%ifarch s390x
%define grubcpu s390x
%define platform emu
%endif

%ifarch aarch64
%define grubcpu arm64
%define platform efi
%define only_efi 1
%endif

%ifarch %{arm}
%define grubcpu arm
%define platform efi
%define only_efi 1
%endif

%define grubarch %{grubcpu}-%{platform}

# build efi bootloader on some platforms only:
%if ! 0%{?efi:1}
%global efi %{ix86} x86_64 ia64 aarch64 %{arm}
%endif

%ifarch %{efi}
%ifarch %{ix86}
%define grubefiarch i386-efi
%else
%ifarch aarch64
%define grubefiarch arm64-efi
%else
%ifarch %{arm}
%define grubefiarch arm-efi
%else
%define grubefiarch %{_target_cpu}-efi
%endif
%endif
%endif
%endif

%if %{platform} == emu
# force %{emu} to 1, e.g. for s390
%define emu 1
%endif

%if 0%{?suse_version} == 1110
%define only_efi %{nil}
%define only_x86_64 %{nil}
%endif

Version:        2.02
Release:        4.1
Summary:        Bootloader with support for Linux, Multiboot and more
License:        GPL-3.0+
Group:          System/Boot
Url:            http://www.gnu.org/software/grub/
%define rev 20120622
Source0:        grub-%{version}.tar.xz
Source1:        90_persistent
Source2:        grub.default
Source3:        README.openSUSE
Source4:        grub2.rpmlintrc
# rsync -Lrtvz  translationproject.org::tp/latest/grub/ po
Source5:        translations-20170427.tar.xz
Source6:        grub2-once
Source7:        20_memtest86+
Source8:        README.ibm3215
Source10:       openSUSE-UEFI-CA-Certificate.crt
Source11:       SLES-UEFI-CA-Certificate.crt
Source12:       grub2-snapper-plugin.sh
Source14:       80_suse_btrfs_snapshot
Source15:       grub2-once.service
Source16:       grub2-xen-pv-firmware.cfg
# required hook for systemd-sleep (bsc#941758)
Source17:       grub2-systemd-sleep.sh
Source1000:     PATCH_POLICY
Patch1:         rename-grub-info-file-to-grub2.patch
Patch2:         grub2-linux.patch
Patch3:         use-grub2-as-a-package-name.patch
Patch6:         grub2-iterate-and-hook-for-extended-partition.patch
Patch8:         grub2-ppc-terminfo.patch
Patch9:         grub2-GRUB_CMDLINE_LINUX_RECOVERY-for-recovery-mode.patch
Patch10:        grub2-fix-error-terminal-gfxterm-isn-t-found.patch
Patch12:        grub2-fix-menu-in-xen-host-server.patch
Patch15:        not-display-menu-when-boot-once.patch
Patch17:        grub2-pass-corret-root-for-nfsroot.patch
Patch18:        grub2-fix-locale-en.mo.gz-not-found-error-message.patch
Patch19:        grub2-efi-HP-workaround.patch
Patch21:        grub2-secureboot-add-linuxefi.patch
Patch22:        grub2-secureboot-use-linuxefi-on-uefi.patch
Patch23:        grub2-secureboot-no-insmod-on-sb.patch
Patch24:        grub2-secureboot-provide-linuxefi-config.patch
Patch25:        grub2-secureboot-chainloader.patch
Patch26:        grub2-secureboot-use-linuxefi-on-uefi-in-os-prober.patch
Patch27:        grub2-linuxefi-fix-boot-params.patch
Patch35:        grub2-linguas.sh-no-rsync.patch
Patch37:        grub2-use-Unifont-for-starfield-theme-terminal.patch
Patch38:        grub2-s390x-01-Changes-made-and-files-added-in-order-to-allow-s390x.patch
Patch39:        grub2-s390x-02-kexec-module-added-to-emu.patch
Patch40:        grub2-s390x-03-output-7-bit-ascii.patch
Patch41:        grub2-s390x-04-grub2-install.patch
Patch42:        grub2-s390x-05-grub2-mkconfig.patch
Patch43:        grub2-s390x-06-loadparm.patch
Patch44:        grub2-s390x-07-add-image-param-for-zipl-setup.patch
Patch45:        grub2-s390x-08-workaround-part-to-disk.patch
Patch49:        grub2-commands-introduce-read_file-subcommand.patch
Patch50:        grub2-mkconfig-aarch64.patch
Patch53:        grub2-getroot-treat-mdadm-ddf-as-simple-device.patch
Patch56:        grub2-setup-try-fs-embed-if-mbr-gap-too-small.patch
Patch58:        grub2-xen-linux16.patch
Patch59:        grub2-efi-disable-video-cirrus-and-bochus.patch
Patch60:        grub2-editenv-add-warning-message.patch
Patch61:        grub2-efi-chainload-harder.patch
Patch62:        grub2-vbe-blacklist-preferred-1440x900x32.patch
Patch65:        grub2-btrfs-workaround-grub2-once.patch
Patch66:        grub2-menu-unrestricted.patch
Patch67:        grub2-default-distributor.patch
Patch74:        grub2-use-stat-instead-of-udevadm-for-partition-lookup.patch
Patch75:        fix-grub2-use-stat-instead-of-udevadm-for-partition-lookup-with-new-glibc.patch
Patch76:        0002-Add-Virtual-LAN-support.patch 
Patch77:        grub2-efi_gop-avoid-low-resolution.patch
Patch78:        grub2-lvm-allocate-metadata-buffer-from-raw-contents.patch
Patch79:        grub2-diskfilter-support-pv-without-metadatacopies.patch
Patch80:        grub2-efi-uga-64bit-fb.patch
# Btrfs snapshot booting related patches
Patch101:       grub2-btrfs-01-add-ability-to-boot-from-subvolumes.patch
Patch102:       grub2-btrfs-02-export-subvolume-envvars.patch
Patch103:       grub2-btrfs-03-follow_default.patch
Patch104:       grub2-btrfs-04-grub2-install.patch
Patch105:       grub2-btrfs-05-grub2-mkconfig.patch
Patch106:       grub2-btrfs-06-subvol-mount.patch
Patch107:       grub2-btrfs-07-subvol-fallback.patch
Patch108:       grub2-btrfs-08-workaround-snapshot-menu-default-entry.patch
Patch109:       grub2-btrfs-09-get-default-subvolume.patch
# Support EFI xen loader (efistub)
Patch120:       grub2-efi-xen-chainload.patch
Patch121:       grub2-efi-chainloader-root.patch
Patch122:       grub2-efi-xen-cmdline.patch
Patch123:       grub2-efi-xen-cfg-unquote.patch
# Linux Root device related fixes
Patch134:       grub2-zipl-setup-fix-btrfs-multipledev.patch
Patch135:       grub2-suse-remove-linux-root-param.patch
# POWER patches
Patch205:       grub2-ppc64le-disable-video.patch
Patch206:       grub2-ppc64le-memory-map.patch
Patch209:       grub2-ppc64-cas-reboot-support.patch
# Support for "t" hotkey to switch to text mode (bsc#976836)
Patch245:       grub2-Add-hidden-menu-entries.patch
Patch246:       grub2-SUSE-Add-the-t-hotkey.patch
# UEFI IPv6 PXE booting support
Patch250:       0001-misc-fix-invalid-character-recongition-in-strto-l.patch
Patch251:       0002-net-read-bracketed-ipv6-addrs-and-port-numbers.patch
Patch252:       0003-bootp-New-net_bootp6-command.patch
Patch253:       0004-efinet-UEFI-IPv6-PXE-support.patch
Patch254:       0005-grub.texi-Add-net_bootp6-doument.patch
Patch255:       0006-bootp-Add-processing-DHCPACK-packet-from-HTTP-Boot.patch
Patch256:       0007-efinet-Setting-network-from-UEFI-device-path.patch
Patch257:       0008-efinet-Setting-DNS-server-from-UEFI-protocol.patch
# EFI free memory on exit fix (bsc#980739)
Patch282:       grub2-efi-Move-grub_reboot-into-kernel.patch
Patch283:       grub2-efi-Free-malloc-regions-on-exit.patch
Patch284:       grub2-emu-4-all.patch
# PATCH-FIX-OPENSUSE grub2-mkconfig-arm.patch bnc#1008568
Patch311:       grub2-mkconfig-arm.patch
# Fix GOP BLT support (FATE#322332)
Patch312:       grub2-efi-gop-add-blt.patch
# TPM Support (FATE#315831)
Patch400:       0001-tpm-Core-TPM-support.patch
Patch401:       0002-tpm-Measure-kernel-initrd.patch
Patch402:       0003-tpm-Add-BIOS-boot-measurement.patch
Patch403:       0004-tpm-Rework-linux-command.patch
Patch404:       0005-tpm-Rework-linux16-command.patch
Patch405:       0006-tpm-Measure-kernel-and-initrd-on-BIOS-systems.patch
Patch406:       0007-tpm-Measure-the-kernel-commandline.patch
Patch407:       0008-tpm-Measure-commands.patch
Patch408:       0009-tpm-Measure-multiboot-images-and-modules.patch
Patch409:       0010-tpm-Fix-boot-when-there-s-no-TPM.patch
Patch410:       0011-tpm-Fix-build-error.patch
Patch411:       0012-tpm-Build-tpm-as-module.patch
Patch412:       0013-tpm-i386-pc-diskboot-img.patch

Requires:       gettext-runtime
%if 0%{?suse_version} >= 1140
%ifnarch s390x
Recommends:     os-prober
%endif
Recommends:     libburnia-tools
%endif
Requires(post): /sbin/install-info
Requires(preun):/sbin/install-info
%if ! 0%{?only_efi:1}
Requires:       grub2-%{grubarch} = %{version}-%{release}
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?only_x86_64:1}
ExclusiveArch:  x86_64
%else
ExclusiveArch:  %{ix86} x86_64 ppc ppc64 ppc64le s390x aarch64 %{arm}
%endif

%description
This is the second version of the GRUB (Grand Unified Bootloader), a
highly configurable and customizable bootloader with modular
architecture.  It support rich scale of kernel formats, file systems,
computer architectures and hardware devices.

This package includes user space utlities to manage GRUB on your system.


Authors:
--------
    Gordon Matzigkeit
    Yoshinori K. Okuji
    Colin Watson
    Colin D. Bennett
    Vesa Jääskeläinen
    Robert Millan
    Carles Pina

%package branding-upstream

Summary:        Upstream branding for GRUB2's graphical console
Group:          System/Fhs
Requires:       %{name} = %{version}-%{release}

%description branding-upstream
Upstream branding for GRUB2's graphical console

%if ! 0%{?only_efi:1}
%package %{grubarch}

Summary:        Bootloader with support for Linux, Multiboot and more
Group:          System/Boot
Requires:       %{name} = %{version}-%{release}
Requires(post):	%{name} = %{version}-%{release}
Requires:       perl-Bootloader
Requires(post): perl-Bootloader
%ifarch s390x
Requires:       /sbin/showconsole
Requires:       kexec-tools
Requires:       s390-tools
%endif
%ifarch ppc64 ppc64le
Requires:       powerpc-utils
%endif

%description %{grubarch}
The GRand Unified Bootloader (GRUB) is a highly configurable and customizable
bootloader with modular architecture.  It supports rich variety of kernel formats,
file systems, computer architectures and hardware devices.  This subpackage
provides support for %{platform} systems.

%endif

%ifarch %{efi}

%package %{grubefiarch}

Summary:        Bootloader with support for Linux, Multiboot and more
Group:          System/Boot
%ifarch aarch64 ia64 x86_64
#Package is available on ia64 and x86_64 only and not necessarily needed
Requires:       efibootmgr
Requires(post): efibootmgr
%endif
%ifarch ppc ppc64 ppc64le
Requires:       powerpc-utils
%endif
Requires:       %{name} = %{version}-%{release}
Requires(post):	%{name} = %{version}-%{release}
Requires:       perl-Bootloader >= 0.706
Requires(post): perl-Bootloader >= 0.706
Provides:       %{name}-efi = %{version}-%{release}
Obsoletes:      %{name}-efi < %{version}-%{release}

%description %{grubefiarch}
The GRand Unified Bootloader (GRUB) is a highly configurable and customizable
bootloader with modular architecture.  It supports rich variety of kernel formats,
file systems, computer architectures and hardware devices.  This subpackage
provides support for EFI systems.

%endif

%ifarch x86_64

%package %{_target_cpu}-xen

Summary:        Bootloader with support for Linux, Multiboot and more
Group:          System/Boot
Provides:       %{name}-xen = %{version}-%{release}
Obsoletes:      %{name}-xen < %{version}-%{release}

%description %{_target_cpu}-xen
The GRand Unified Bootloader (GRUB) is a highly configurable and customizable
bootloader with modular architecture.  It supports rich variety of kernel formats,
file systems, computer architectures and hardware devices.  This subpackage
provides support for XEN systems.

%endif

%package snapper-plugin

Summary:        Grub2's snapper plugin
Group:          System/Fhs
Requires:       %{name} = %{version}-%{release}
Requires:       libxml2-tools
Supplements:    packageand(snapper:grub2)
BuildArch:      noarch

%description snapper-plugin
Grub2's snapper plugin for advanced btrfs snapshot boot menu management

%if 0%{?has_systemd:1}
%package systemd-sleep-plugin

Summary:        Grub2's systemd-sleep plugin
Group:          System/Fhs
Requires:       grub2
Requires:       util-linux
Supplements:    packageand(systemd:grub2)
BuildArch:      noarch

%description systemd-sleep-plugin
Grub2's systemd-sleep plugin for directly booting hibernated kernel image in
swap partition while in resuming
%endif

%prep
# We create (if we build for efi) two copies of the sources in the Builddir
%setup -q -n grub-%{version} -a 5
(cd po && ls *.po | cut -d. -f1 | xargs) >po/LINGUAS
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch6 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch12 -p1
%patch15 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch35 -p1
%patch37 -p1
%patch38 -p1
%patch39 -p1
%patch40 -p1
%patch41 -p1
%patch42 -p1
%patch43 -p1
%patch44 -p1
%patch45 -p1
# The follow patch is needed for bnc#891946/892852 exclusively on s390x
# It doesn't help to add this to common code just now.
%ifarch s390x
%patch49 -p1
%endif
%patch50 -p1
%patch53 -p1
%patch56 -p1
%patch58 -p1
%patch59 -p1
%patch60 -p1
%patch61 -p1
%patch62 -p1
%patch65 -p1
%patch66 -p1
%patch67 -p1
%patch74 -p1
%patch75 -p1
%patch76 -p1
%patch77 -p1
%patch78 -p1
%patch79 -p1
%patch80 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch120 -p1
%patch121 -p1
%patch122 -p1
%patch123 -p1
%patch134 -p1
%patch135 -p1
#POWER
%patch205 -p1
%patch206 -p1
%patch209 -p1
%patch245 -p1
%patch246 -p1
%patch250 -p1
%patch251 -p1
%patch252 -p1
%patch253 -p1
%patch254 -p1
%patch255 -p1
%patch256 -p1
%patch257 -p1
%patch282 -p1
%patch283 -p1
%patch284 -p1
%patch311 -p1
%patch312 -p1
%patch400 -p1
%patch401 -p1
%patch402 -p1
%patch403 -p1
%patch404 -p1
%patch405 -p1
%patch406 -p1
%patch407 -p1
%patch408 -p1
%patch409 -p1
%patch410 -p1
%patch411 -p1
%patch412 -p1

# This simplifies patch handling without need to use git to create patch
# that renames file
mv docs/grub.texi docs/grub2.texi
# This avoids attempt to rebuild potfiles which fails because necessary
# sources are not included in tarball
mv po/grub.pot po/%{name}.pot

# Generate po/LINGUAS for message catalogs ...
./linguas.sh
# ... and make sure new catalogs are actually created
rm -f po/stamp-po

# README.openSUSE
cp --preserve=timestamps %{SOURCE3} .
cp --preserve=timestamps %{SOURCE8} .
mkdir build
%ifarch %{efi}
mkdir build-efi
%endif
%ifarch x86_64
mkdir build-xen
%endif
%if %{emu}
mkdir build-emu
%endif

%build
# autogen calls autoreconf -vi
./autogen.sh
# Not yet:
%define common_conf_options TARGET_LDFLAGS=-static --program-transform-name=s,grub,%{name},
# This does NOT work on SLE11:
%define _configure ../configure

# We don't want to let rpm override *FLAGS with default a.k.a bogus values.
CFLAGS="-fno-strict-aliasing -fno-inline-functions-called-once "
CXXFLAGS=" "
FFLAGS=" "
export CFLAGS CXXFLAGS FFLAGS

%if %{emu}
cd build-emu
%define arch_specific --enable-device-mapper --disable-grub-mount
TFLAGS="-fPIC"

# -static is needed so that autoconf script is able to link
# test that looks for _start symbol on 64 bit platforms
../configure TARGET_LDFLAGS=$TFLAGS     \
	--prefix=%{_prefix}		\
	--sysconfdir=%{_sysconfdir}	\
        --target=%{_target_platform}    \
        --with-platform=emu     \
	%{arch_specific}                \
        --program-transform-name=s,grub,%{name},
make %{?_smp_mflags}
cd ..
if [ "%{platform}" = "emu" ]; then
  rmdir build
  mv build-emu build
fi
%endif

%ifarch x86_64
cd build-xen
../configure                           \
        TARGET_LDFLAGS=-static         \
        --prefix=%{_prefix}            \
        --sysconfdir=%{_sysconfdir}    \
        --target=%{_target_platform}   \
        --libdir=%{_libdir}            \
        --with-platform=xen            \
        --program-transform-name=s,grub,%{name},
make %{?_smp_mflags}

./grub-mkstandalone --grub-mkimage=./grub-mkimage -o grub.xen -O %{_target_cpu}-xen -d grub-core/ "/boot/grub/grub.cfg=%{SOURCE16}"

cd ..
%endif

%ifarch %{efi}
cd build-efi
../configure   				                \
        TARGET_LDFLAGS=-static                          \
	--prefix=%{_prefix}				\
	--sysconfdir=%{_sysconfdir}			\
        --target=%{_target_platform}                    \
        --libdir=%{_libdir}                          \
        --with-platform=efi                             \
        --program-transform-name=s,grub,%{name},
make %{?_smp_mflags}

#TODO: add efifwsetup module

FS_MODULES="ext2 btrfs ext2 xfs jfs reiserfs"
CD_MODULES=" all_video boot cat chain configfile echo true \
		efinet font gfxmenu gfxterm gzio halt iso9660 \
		jpeg minicmd normal part_apple part_msdos part_gpt \
		password_pbkdf2 png reboot search search_fs_uuid \
		search_fs_file search_label sleep test video fat loadenv"
PXE_MODULES="efinet tftp http"
CRYPTO_MODULES="luks gcry_rijndael gcry_sha1"

%ifarch x86_64
CD_MODULES="${CD_MODULES} linuxefi" 
%else
CD_MODULES="${CD_MODULES} linux" 
%endif

GRUB_MODULES="${CD_MODULES} ${FS_MODULES} ${PXE_MODULES} ${CRYPTO_MODULES} mdraid09 mdraid1x lvm"
./grub-mkimage -O %{grubefiarch} -o grub.efi --prefix= \
		-d grub-core ${GRUB_MODULES}
./grub-mkimage -O %{grubefiarch} -o grub-tpm.efi --prefix= \
		-d grub-core ${GRUB_MODULES} tpm
#./grub-mkimage -O #{grubefiarch} -o grub.efi -d grub-core part_gpt hfsplus fat \
#        ext2 btrfs normal chain boot configfile linux appleldr minicmd \
#        loadbios reboot halt search font gfxterm

%ifarch x86_64
%if 0%{?suse_version} >= 1230 || 0%{?suse_version} == 1110
if test -e %{_sourcedir}/_projectcert.crt ; then
    prjsubject=$(openssl x509 -in %{_sourcedir}/_projectcert.crt -noout -subject_hash)
    prjissuer=$(openssl x509 -in %{_sourcedir}/_projectcert.crt -noout -issuer_hash)
    opensusesubject=$(openssl x509 -in %{SOURCE10} -noout -subject_hash)
    slessubject=$(openssl x509 -in %{SOURCE11} -noout -subject_hash)
    if test "$prjissuer" = "$opensusesubject" ; then
        cert=%{SOURCE10}
    fi
    if test "$prjissuer" = "$slessubject" ; then
        cert=%{SOURCE11}
    fi
    if test "$prjsubject" = "$prjissuer" ; then
        cert=%{_sourcedir}/_projectcert.crt
    fi
fi
if test -z "$cert" ; then
    echo "cannot identify project, assuming openSUSE signing"
    cert=%{SOURCE10}
fi

openssl x509 -in $cert -outform DER -out grub.der
%endif
%endif

cd ..
%endif

%if ! 0%{?only_efi:1}
cd build

# 64-bit x86-64 machines use 32-bit boot loader
# (We cannot just redefine _target_cpu, as we'd get i386.rpm packages then)
%ifarch x86_64 
%define _target_platform i386-%{_vendor}-%{_target_os}%{?_gnu}
%endif

%if %{platform} != "emu"
%define arch_specific --enable-device-mapper
TFLAGS="-static"

# -static is needed so that autoconf script is able to link
# test that looks for _start symbol on 64 bit platforms
../configure TARGET_LDFLAGS=$TFLAGS     \
	--prefix=%{_prefix}		\
	--sysconfdir=%{_sysconfdir}	\
        --target=%{_target_platform}    \
        --with-platform=%{platform}     \
	%{arch_specific}                \
        --program-transform-name=s,grub,%{name},
make %{?_smp_mflags}
%endif
cd ..
%endif

%install

%ifarch x86_64
cd build-xen
make DESTDIR=$RPM_BUILD_ROOT install
install -m 644 grub.xen $RPM_BUILD_ROOT%{_libdir}/%{name}/%{_target_cpu}-xen/.
cd ..
%endif

%ifarch %{efi}
cd build-efi
make DESTDIR=$RPM_BUILD_ROOT install

install -m 644 grub.efi grub-tpm.efi $RPM_BUILD_ROOT%{_libdir}/%{name}/%{grubefiarch}/.

# Create grub.efi link to system efi directory
# This is for tools like kiwi not fiddling with the path
%if "%{grubefiarch}" == "x86_64-efi"
%define sysefidir %{_exec_prefix}/lib64/efi
%else
%define sysefidir %{_libdir}/efi
%endif
install -d $RPM_BUILD_ROOT%{sysefidir}
ln -sf ../../../%{_libdir}/%{name}/%{grubefiarch}/grub.efi $RPM_BUILD_ROOT%{sysefidir}/grub.efi

%ifarch x86_64
%if 0%{?suse_version} >= 1230 || 0%{?suse_version} == 1110
export BRP_PESIGN_FILES="%{_libdir}/%{name}/%{grubefiarch}/grub.efi %{_libdir}/%{name}/%{grubefiarch}/grub-tpm.efi"
install -m 444 grub.der $RPM_BUILD_ROOT%{sysefidir}/
%endif
%endif

cd ..
%endif

%if ! 0%{?only_efi:1}
cd build
make DESTDIR=$RPM_BUILD_ROOT install
cd ..
%endif

if [ -d build-emu/grub-core ]; then
  cd build-emu/grub-core
  install -m 755 grub-emu $RPM_BUILD_ROOT%{_bindir}/%{name}-emu
  install -m 755 grub-emu-lite $RPM_BUILD_ROOT%{_bindir}/%{name}-emu-lite
  install -m 644 grub-emu.1 $RPM_BUILD_ROOT%{_mandir}/man1/%{name}-emu.1
  cd ../..
fi

# *.module files are installed with executable bits due to the way grub2 build
# system works. Clear executable bits to not confuse find-debuginfo.sh
find $RPM_BUILD_ROOT%{_libdir}/%{name} \
       \( -name '*.module' -o -name '*.image' -o -name '*.exec' \) -print0 | \
       xargs --no-run-if-empty -0 chmod a-x

# Script that makes part of grub.cfg persist across updates
install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/grub.d/

# Script to generate memtest86+ menu entry
install -m 755 %{SOURCE7} $RPM_BUILD_ROOT%{_sysconfdir}/grub.d/

# Ghost config file
install -d $RPM_BUILD_ROOT/boot/%{name}
touch $RPM_BUILD_ROOT/boot/%{name}/grub.cfg

# Remove devel files
rm $RPM_BUILD_ROOT/%{_libdir}/%{name}/*/*.h
%if 0%{?suse_version} >= 1140
rm $RPM_BUILD_ROOT%{_datadir}/%{name}/*.h
%endif

# Defaults
install -m 644 -D %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/default/grub
install -m 755 -D %{SOURCE6} $RPM_BUILD_ROOT%{_sbindir}/grub2-once
install -m 755 -D %{SOURCE12} $RPM_BUILD_ROOT%{_libdir}/snapper/plugins/grub
install -m 755 -D %{SOURCE14} $RPM_BUILD_ROOT%{_sysconfdir}/grub.d/80_suse_btrfs_snapshot
%if 0%{?has_systemd:1}
install -m 644 -D %{SOURCE15} $RPM_BUILD_ROOT%{_unitdir}/grub2-once.service
install -m 755 -D %{SOURCE17} $RPM_BUILD_ROOT%{_libdir}/systemd/system-sleep/grub2.sleep
%endif

R=$RPM_BUILD_ROOT
%ifarch %{ix86} x86_64
%else
rm -f $R%{_sysconfdir}/grub.d/20_memtest86+
%endif

%ifarch ppc ppc64 ppc64le
%else
rm -f $R%{_sysconfdir}/grub.d/20_ppc_terminfo
%endif

%ifarch s390x
mv $R%{_sysconfdir}/{grub.d,default}/zipl2grub.conf.in
chmod 600 $R%{_sysconfdir}/default/zipl2grub.conf.in

%define dracutlibdir %{_prefix}/lib/dracut
%define dracutgrubmoddir %{dracutlibdir}/modules.d/99grub2
install -m 755 -d $R%{dracutgrubmoddir}
for f in module-setup.sh grub2.sh; do
  mv $R%{_libdir}/%{name}/%{grubarch}/dracut-$f $R%{dracutgrubmoddir}/$f
done
rm -f $R%{_sysconfdir}/grub.d/30_os-prober

perl -ni -e '
  sub END() {
    print "\n# on s390x always:\nGRUB_DISABLE_OS_PROBER=true\n";
  }
  if ( s{^#(GRUB_DISABLE_LINUX_RECOVERY)=\"?(true)\"?}{$1=$2} ) {
    $_ .= "GRUB_DISABLE_RECOVERY=true\n";
  }
  if ( s{^#?(GRUB_TERMINAL)=(console|gfxterm)}{$1=console} ) {
    $_ .= "GRUB_GFXPAYLOAD_LINUX=text\n";
  }
  if (	m{^# The resolution used on graphical} ||
	m{^# # note that you can use only modes} ||
	m{^# you can see them in real GRUB} ||
	m{^#?GRUB_GFXMODE=} ) {
    next;
  }
  s{openSUSE}{SUSE Linux Enterprise Server} if (m{^GRUB_DISTRIBUTOR});
  print;
'  $RPM_BUILD_ROOT%{_sysconfdir}/default/grub
%else
%endif

%find_lang %{name}
%fdupes %buildroot%{_bindir}
%fdupes %buildroot%{_libdir}

%post
/sbin/install-info %{_infodir}/grub-dev.info %{_infodir}/dir || :
/sbin/install-info %{_infodir}/%{name}.info %{_infodir}/dir || :

%if ! 0%{?only_efi:1}

%post %{grubarch}
# To check by current loader settings
if [ -f %{_sysconfdir}/sysconfig/bootloader ]; then
  . %{_sysconfdir}/sysconfig/bootloader
fi

# If the grub is the current loader, we'll handle the grub2 testing entry
if [ "x${LOADER_TYPE}" = "xgrub" ]; then

  exec >/dev/null 2>&1

  # check if entry for grub2's core.img exists in the config
  # if yes, we will correct obsoleted path and update grub2 stuff and config to make it work
  # if no, do nothing
  if [ -f /boot/grub/menu.lst ]; then

    # If grub config contains obsolete core.img path, remove and use the new one
    if /usr/bin/grep -l "^\s*kernel\s*.*/boot/%{name}/core.img" /boot/grub/menu.lst; then
      /sbin/update-bootloader --remove --image /boot/%{name}/core.img || true
      /sbin/update-bootloader --add --image /boot/%{name}/i386-pc/core.img --name "GNU GRUB 2" || true
    fi

    # Install grub2 stuff and config to make the grub2 testing entry to work with updated version
    if /usr/bin/grep -l "^\s*kernel\s*.*/boot/%{name}/i386-pc/core.img" /boot/grub/menu.lst; then
      # Determine the partition with /boot
      BOOT_PARTITION=$(df -h /boot |(read; awk '{print $1; exit}'))
      # Generate core.img, but don't let it be installed in boot sector
      %{name}-install --no-bootsector $BOOT_PARTITION || true
      # Create a working grub2 config, otherwise that entry is un-bootable
      /usr/sbin/grub2-mkconfig -o /boot/%{name}/grub.cfg
    fi
  fi

elif [ "x${LOADER_TYPE}" = "xgrub2" ]; then

  # It's enought to call update-bootloader to install grub2 and update it's config
  # Use new --reinit, if not available use --refresh
  # --reinit: install and update bootloader config
  # --refresh: update bootloader config
  /sbin/update-bootloader --reinit 2>&1 | grep -q 'Unknown option: reinit' &&
  /sbin/update-bootloader --refresh || true
fi
%endif

%ifarch %{efi}

%post %{grubefiarch}

# To check by current loader settings
if [ -f %{_sysconfdir}/sysconfig/bootloader ]; then
  . %{_sysconfdir}/sysconfig/bootloader
fi

if [ "x${LOADER_TYPE}" = "xgrub2-efi" ]; then

  if [ -d /boot/%{name}-efi ]; then
    # Migrate settings to standard prefix /boot/grub2
    for i in custom.cfg grubenv; do
      [ -f /boot/%{name}-efi/$i ] && cp -a /boot/%{name}-efi/$i /boot/%{name} || :
    done

  fi

  # It's enough to call update-bootloader to install grub2 and update it's config
  # Use new --reinit, if not available use --refresh
  # --reinit: install and update bootloader config
  # --refresh: update bootloader config
  /sbin/update-bootloader --reinit 2>&1 | grep -q 'Unknown option: reinit' &&
  /sbin/update-bootloader --refresh || true
fi

if [ -d /boot/%{name}-efi ]; then
  mv /boot/%{name}-efi /boot/%{name}-efi.rpmsave
fi

exit 0
%endif

%preun
if [ $1 = 0 ]; then
  /sbin/install-info --delete %{_infodir}/grub-dev.info %{_infodir}/dir || :
  /sbin/install-info --delete %{_infodir}/%{name}.info %{_infodir}/dir || :

%if ! 0%{?only_efi:1}
  # To check by current loader settings
  if [ -f %{_sysconfdir}/sysconfig/bootloader ]; then
    . %{_sysconfdir}/sysconfig/bootloader
  fi

  if [ "x${LOADER_TYPE}" = "xgrub" ]; then

    exec >/dev/null 2>&1

    if [ -f /boot/grub/menu.lst ]; then

      # Remove grub2 testing entry in menu.lst if has any
      for i in /boot/%{name}/core.img /boot/%{name}/i386-pc/core.img; do
        if /usr/bin/grep -l "^\s*kernel\s*.*$i" /boot/grub/menu.lst; then
          /sbin/update-bootloader --remove --image "$i" || true
        fi
      done
    fi

    # Cleanup config, to not confuse some tools determining bootloader in use
    rm -f /boot/%{name}/grub.cfg

    # Cleanup installed files
    # Unless grub2 provides grub2-uninstall, we don't remove any file because
    # we have no idea what's been installed. (And a blind remove is dangerous
    # to remove user's or other package's file accidently ..)
  fi
%endif
fi

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc COPYING NEWS README
%doc THANKS TODO ChangeLog
%doc README.openSUSE
%doc docs/autoiso.cfg docs/osdetect.cfg
%ifarch s390x
%doc README.ibm3215
%endif
%dir /boot/%{name}
%ghost /boot/%{name}/grub.cfg
%{_sysconfdir}/bash_completion.d/grub
%config(noreplace) %{_sysconfdir}/default/grub
%dir %{_sysconfdir}/grub.d
%{_sysconfdir}/grub.d/README
%config %{_sysconfdir}/grub.d/00_header
%config %{_sysconfdir}/grub.d/10_linux
%config %{_sysconfdir}/grub.d/20_linux_xen
%config %{_sysconfdir}/grub.d/40_custom
%config %{_sysconfdir}/grub.d/41_custom
%config %{_sysconfdir}/grub.d/90_persistent
%config %{_sysconfdir}/grub.d/95_textmode
%{_sbindir}/%{name}-install
%{_sbindir}/%{name}-mkconfig
%{_sbindir}/%{name}-once
%{_sbindir}/%{name}-probe
%{_sbindir}/%{name}-reboot
%{_sbindir}/%{name}-set-default
%{_bindir}/%{name}-editenv
%{_bindir}/%{name}-file
%{_bindir}/%{name}-fstest
%{_bindir}/%{name}-kbdcomp
%{_bindir}/%{name}-menulst2cfg
%{_bindir}/%{name}-mkfont
%{_bindir}/%{name}-mkimage
%{_bindir}/%{name}-mklayout
%{_bindir}/%{name}-mknetdir
%{_bindir}/%{name}-mkpasswd-pbkdf2
%{_bindir}/%{name}-mkrelpath
%{_bindir}/%{name}-mkrescue
%{_bindir}/%{name}-mkstandalone
%{_bindir}/%{name}-render-label
%{_bindir}/%{name}-script-check
%{_bindir}/%{name}-syslinux2cfg
%if 0%{?has_systemd:1}
%{_unitdir}/grub2-once.service
%endif
%dir %{_libdir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/themes
%if 0%{?suse_version} >= 1140
%{_datadir}/%{name}/*.pf2
%endif
%{_datadir}/%{name}/grub-mkconfig_lib
%{_infodir}/grub-dev.info*
%{_infodir}/%{name}.info*
%{_mandir}/man1/%{name}-editenv.1.*
%{_mandir}/man1/%{name}-file.1.*
%{_mandir}/man1/%{name}-fstest.1.*
%{_mandir}/man1/%{name}-kbdcomp.1.*
%{_mandir}/man1/%{name}-menulst2cfg.1.*
%{_mandir}/man1/%{name}-mkfont.1.*
%{_mandir}/man1/%{name}-mkimage.1.*
%{_mandir}/man1/%{name}-mklayout.1.*
%{_mandir}/man1/%{name}-mknetdir.1.*
%{_mandir}/man1/%{name}-mkpasswd-pbkdf2.1.*
%{_mandir}/man1/%{name}-mkrelpath.1.*
%{_mandir}/man1/%{name}-mkrescue.1.*
%{_mandir}/man1/%{name}-mkstandalone.1.*
%{_mandir}/man1/%{name}-render-label.1.*
%{_mandir}/man1/%{name}-script-check.1.*
%{_mandir}/man1/%{name}-syslinux2cfg.1.*
%{_mandir}/man8/%{name}-install.8.*
%{_mandir}/man8/%{name}-mkconfig.8.*
%{_mandir}/man8/%{name}-probe.8.*
%{_mandir}/man8/%{name}-reboot.8.*
%{_mandir}/man8/%{name}-set-default.8.*
%if %{emu}
%{_bindir}/%{name}-emu*
%{_mandir}/man1/%{name}-emu.1.*
%endif
%ifnarch s390x
%config %{_sysconfdir}/grub.d/30_os-prober
%{_bindir}/%{name}-glue-efi
%{_bindir}/%{name}-mount
%{_sbindir}/%{name}-bios-setup
%{_sbindir}/%{name}-macbless
%{_sbindir}/%{name}-ofpathname
%{_sbindir}/%{name}-sparc64-setup
%{_mandir}/man1/%{name}-glue-efi.1.*
%{_mandir}/man1/%{name}-mount.1.*
%{_mandir}/man8/%{name}-bios-setup.8.*
%{_mandir}/man8/%{name}-macbless.8.*
%{_mandir}/man8/%{name}-ofpathname.8.*
%{_mandir}/man8/%{name}-sparc64-setup.8.*
%endif

%files branding-upstream
%defattr(-,root,root,-)
%{_datadir}/%{name}/themes/starfield

%if ! 0%{?only_efi:1}

%files %{grubarch}
%defattr(-,root,root,-)
%ifarch %{ix86} x86_64
%config %{_sysconfdir}/grub.d/20_memtest86+
%endif
%dir %{_libdir}/%{name}/%{grubarch}
%ifarch ppc ppc64 ppc64le
%config %{_sysconfdir}/grub.d/20_ppc_terminfo
# This is intentionally "grub.chrp" and not "%{name}.chrp"
%{_libdir}/%{name}/%{grubarch}/grub.chrp
%{_libdir}/%{name}/%{grubarch}/bootinfo.txt
%endif
%ifnarch ppc ppc64 ppc64le s390x
%{_libdir}/%{name}/%{grubarch}/*.image
%endif
%{_libdir}/%{name}/%{grubarch}/*.img
%{_libdir}/%{name}/%{grubarch}/*.lst
%{_libdir}/%{name}/%{grubarch}/*.mod
%{_libdir}/%{name}/%{grubarch}/*.module
%ifarch x86_64
%{_libdir}/%{name}/%{grubarch}/efiemu*.o
%endif
%{_libdir}/%{name}/%{grubarch}/gdb_grub
%{_libdir}/%{name}/%{grubarch}/gmodule.pl
%{_libdir}/%{name}/%{grubarch}/kernel.exec
%{_libdir}/%{name}/%{grubarch}/modinfo.sh
%endif
%ifarch s390x
%{_sbindir}/%{name}-zipl-setup
%config(noreplace) %{_sysconfdir}/default/zipl2grub.conf.in
%{dracutlibdir}
%endif

%ifarch %{efi}

%files %{grubefiarch}
%defattr(-,root,root,-)
%dir %{_libdir}/%{name}/%{grubefiarch}
%{_libdir}/%{name}/%{grubefiarch}/grub.efi
%{_libdir}/%{name}/%{grubefiarch}/grub-tpm.efi
%{_libdir}/%{name}/%{grubefiarch}/*.img
%{_libdir}/%{name}/%{grubefiarch}/*.lst
%{_libdir}/%{name}/%{grubefiarch}/*.mod
%{_libdir}/%{name}/%{grubefiarch}/*.module
%{_libdir}/%{name}/%{grubefiarch}/gdb_grub
%{_libdir}/%{name}/%{grubefiarch}/gmodule.pl
%{_libdir}/%{name}/%{grubefiarch}/kernel.exec
%{_libdir}/%{name}/%{grubefiarch}/modinfo.sh
%dir %{sysefidir}
%{sysefidir}/grub.efi

%ifarch x86_64
%if 0%{?suse_version} >= 1230 || 0%{?suse_version} == 1110
%{sysefidir}/grub.der
%endif
%endif
%endif

%files snapper-plugin
%defattr(-,root,root,-)
%dir %{_libdir}/snapper
%dir %{_libdir}/snapper/plugins
%config %{_sysconfdir}/grub.d/80_suse_btrfs_snapshot
%{_libdir}/snapper/plugins/grub

%ifarch x86_64
%files %{_target_cpu}-xen
%dir %{_libdir}/%{name}/%{_target_cpu}-xen
%{_libdir}/%{name}/%{_target_cpu}-xen/*
%endif

%if 0%{?has_systemd:1}
%files systemd-sleep-plugin
%defattr(-,root,root,-)
%dir %{_libdir}/systemd/system-sleep
%{_libdir}/systemd/system-sleep/grub2.sleep
%endif

%changelog
* Fri Dec  8 2017 mchang@suse.com
-  Filter out autofs and securityfs from /proc/self/mountinfo to speed
  up nfsroot test in large number of autofs mounts (bsc#1069094)
  * modified grub2-pass-corret-root-for-nfsroot.patch
* Fri Oct 13 2017 mchang@suse.com
- From agraf@suse.com:
- Fix reboot in UEFI environments (bsc#1047331)
  * Add grub2-efi-Move-grub_reboot-into-kernel.patch
  * Update grub2-efi-Free-malloc-regions-on-exit.patch to upstream
    reviewed commit which is also included in openSUSE
* Tue Sep 26 2017 mchang@suse.com
- Build diskboot_tpm.img as separate image to diskboot.img to prevent failure
  in booting on some bogus firmware. To use the TPM image you have to use
  suse-enable-tpm option of grub2-install (bsc#1052401)
  * 0013-tpm-i386-pc-diskboot-img.patch
* Sun Sep 24 2017 mchang@suse.com
- From mlatimer@suse.com:
- Use /boot/<arch>/loader/linux to determine if install media
  is SUSE instead of /contents file (bsc#1054453)
- Use the pvops-enabled default kernel if the traditional xen
  pv kernel and initrd are not found (bsc#1054453)
* Thu Jun  1 2017 mchang@suse.com
- Support LVM physical volume created without metadatacopies (bsc#1027526)
  * grub2-diskfilter-support-pv-without-metadatacopies.patch
- Fix page fault exception when grub loads with Nvidia cards (bsc#1038533)
  * grub2-efi-uga-64bit-fb.patch
* Thu Apr 27 2017 arvidjaar@gmail.com
- new upstream version 2.02
  * rediff
  - use-grub2-as-a-package-name.patch
- update translations
* Tue Apr 25 2017 mchang@suse.com
- Grub not working correctly with xen and btrfs snapshots (bsc#1026511)
  * Add grub2-btrfs-09-get-default-subvolume.patch
  * grub2-xen-pv-firmware.cfg : search path in default subvolume
* Thu Apr  6 2017 mchang@suse.com
- Downgrade os-prober dependency to Recommends (boo#898610) (fate#323231)
* Sun Mar 26 2017 arvidjaar@gmail.com
- update grub2-btrfs-workaround-grub2-once.patch to also store saved_entry
  in additional environment block (boo#1031025)
* Mon Mar 20 2017 mchang@suse.com
- Fix out of memory error on lvm detection (bsc#1016536) (bsc#1027401)
  * grub2-lvm-allocate-metadata-buffer-from-raw-contents.patch
- Fix boot failure if /boot is separate btrfs partition (bsc#1023160)
  * grub2-btrfs-06-subvol-mount.patch
* Fri Mar 17 2017 mchang@suse.com
- 0004-tpm-Rework-linux-command.patch : Fix out of bound memory copy
  (bsc#1029187)
* Thu Mar 16 2017 arvidjaar@gmail.com
- new upstream version 2.02~rc2
  * rediff
  - use-grub2-as-a-package-name.patch
  - grub2-linguas.sh-no-rsync.patch
  * drop upstream patches
  - 0001-efi-strip-off-final-NULL-from-File-Path-in-grub_efi_.patch
* Mon Mar  6 2017 mchang@suse.com
- TPM Support (FATE#315831)
  * 0001-tpm-Core-TPM-support.patch
  * 0002-tpm-Measure-kernel-initrd.patch
  * 0003-tpm-Add-BIOS-boot-measurement.patch
  * 0004-tpm-Rework-linux-command.patch
  * 0005-tpm-Rework-linux16-command.patch
  * 0006-tpm-Measure-kernel-and-initrd-on-BIOS-systems.patch
  * 0007-tpm-Measure-the-kernel-commandline.patch
  * 0008-tpm-Measure-commands.patch
  * 0009-tpm-Measure-multiboot-images-and-modules.patch
  * 0010-tpm-Fix-boot-when-there-s-no-TPM.patch
  * 0011-tpm-Fix-build-error.patch
  * 0012-tpm-Build-tpm-as-module.patch
- grub2.spec : Add grub-tpm.efi for Secure Boot
* Fri Mar  3 2017 mchang@suse.com
- Fix invalid Xen EFI config files if xen_args include GRUB2 quoting
  (bsc#900418) (bsc#951748)
  * grub2-efi-xen-cfg-unquote.patch
- Fix linuxefi erroneously initialize linux's boot_params with non-zero
  values. (bsc#1025563)
  * grub2-linuxefi-fix-boot-params.patch
- Removed grub2-fix-multi-device-root-kernel-argument.patch as it has
  regression on how GRUB_DISABLE_LINUX_UUID=true interpreted (bsc#1015138)
* Thu Mar  2 2017 mchang@suse.com
- Fix for openQA UEFI USB Boot failure with upstream patch (bsc#1026344)
  * added 0001-efi-strip-off-final-NULL-from-File-Path-in-grub_efi_.patch
* Fri Feb 17 2017 mchang@suse.com
- New upstream version 2.02~rc1 (fate#322102)
- Drop upstream patches
  * 0001-efidisk-move-device-path-helpers-in-core-for-efinet.patch
  * 0002-efinet-skip-virtual-IPv4-and-IPv6-devices-when-enume.patch
  * 0003-efinet-open-Simple-Network-Protocol-exclusively.patch
  * 0001-unix-password-Fix-file-descriptor-leak.patch
  * 0002-linux-getroot-fix-descriptor-leak.patch
  * 0003-util-grub-mount-fix-descriptor-leak.patch
  * 0004-linux-ofpath-fix-descriptor-leak.patch
  * 0005-grub-fstest-fix-descriptor-leak.patch
  * 0001-grub-core-kern-i386-tsc.c-calibrate_tsc-Ensure-that.patch
  * 0002-i386-tsc-Fix-unused-function-warning-on-xen.patch
  * 0003-acpi-do-not-skip-BIOS-scan-if-EBDA-length-is-zero.patch
  * 0004-tsc-Use-alternative-delay-sources-whenever-appropria.patch
  * 0005-i386-fix-TSC-calibration-using-PIT.patch
  * 0001-efi-really-mark-memory-of-unknown-type-as-reserved.patch
  * 0002-Translate-UEFI-persistent-memory-type.patch
  * 0003-lsefimmap-support-persistent-memory-and-other-UEFI-2.patch
  * 0001-Fix-partmap-cryptodisk-and-abstraction-handling-in-g.patch
  * 0002-disk-cryptodisk-Add-missing-error-check.patch
  * 0003-crypto-restrict-cipher-block-size-to-power-of-2.patch
  * 0004-cryptodisk-strip-parenthesis-from-backing-device-nam.patch
  * 0005-cryptodisk-teach-grub_cryptodisk_insert-about-partit.patch
  * 0006-do-not-emit-cryptomount-without-crypto-UUID.patch
  * 0001-Initialized-initrd_ctx-so-we-don-t-free-a-random-poi.patch
  * 0002-grub-core-disk-lzopio.c-fix-double-free-in-error-pat.patch
  * 0003-fix-double-free-in-grub_net_recv_tcp_packet.patch
  * 0004-arm64-setjmp-Add-missing-move-for-arg1-0-case.patch
  * 0005-tftp-fix-memory-leaks-in-open.patch
  * 0006-Remove-the-variable-oldname-which-is-attempting-to-f.patch
  * 0007-arp-icmp-Fix-handling-in-case-of-oversized-or-invali.patch
  * 0001-Import-xen-headers-directly-into-GRUB.patch
  * 0002-Adapt-build-system-to-use-imported-xen-headers.patch
  * 0003-xen-relocator-Use-local-symbol-to-ensure-that-code-i.patch
  * 0001-xen-make-xen-loader-callable-multiple-times.patch
  * 0002-xen-avoid-memleaks-on-error.patch
  * 0003-xen-reduce-number-of-global-variables-in-xen-loader.patch
  * 0004-xen-add-elfnote.h-to-avoid-using-numbers-instead-of-.patch
  * 0005-xen-synchronize-xen-header.patch
  * 0006-xen-factor-out-p2m-list-allocation-into-separate-fun.patch
  * 0007-xen-factor-out-allocation-of-special-pages-into-sepa.patch
  * 0008-xen-factor-out-allocation-of-page-tables-into-separa.patch
  * 0009-xen-add-capability-to-load-initrd-outside-of-initial.patch
  * 0010-xen-modify-page-table-construction.patch
  * 0011-xen-add-capability-to-load-p2m-list-outside-of-kerne.patch
  * ppc64le.patch
  * libgcc-prereq.patch
  * libgcc.patch
  * grub2-ppc64-qemu.patch
  * biendian.patch
  * ppc64_opt.patch
  * grub2-10_linux-avoid-multi-device-root-kernel-argument.patch
  * 0001-10_linux-Fix-grouping-of-tests-for-GRUB_DEVICE.patch
  * 0002-20_linux_xen-fix-test-for-GRUB_DEVICE.patch
  * grub2-xfs-Add-helper-for-inode-size.patch
  * grub2-xfs-Fix-termination-loop-for-directory-iteration.patch
  * grub2-xfs-Convert-inode-numbers-to-cpu-endianity-immediate.patch
  * grub2-xfs-V5-filesystem-format-support.patch
  * 0001-efinet-Check-for-immediate-completition.patch
  * 0001-efinet-enable-hardware-filters-when-opening-interfac.patch
  * 0001-look-for-DejaVu-also-in-usr-share-fonts-truetype.patch
  * grub2-xen-legacy-config-device-name.patch
  * grub2-getroot-support-NVMe-device-names.patch
  * grub2-netboot-hang.patch
  * grub2-btrfs-fix-incorrect-address-reference.patch
  * aarch64-reloc.patch
  * fix-overflows-in-grub_password_get-and-grub_user_get.patch
  * grub2-xen-fix-bzImage-payload-length.patch
  * 0001-increase-network-try-interval-gradually.patch
  * 0001-grub-core-kern-efi-efi.c-Ensure-that-the-result-star.patch
  * btrfs-fix_get_root_key_comparison_failures_due_to_endianness.patch
  * grub2-getroot-fix-get-btrfs-fs-prefix-big-endian.patch
  * 0001-Add-bootargs-parser-for-open-firmware.patch
  * grub2-arm64-Reduce-timer-event-frequency-by-10.patch
  * grub2-arm64-set-correct-length.patch
  * grub2-arm64-setjmp-Add-missing-license-macro.patch
  * grub2-arm64-efinet-handle-get_status-on-buggy-firmware-properly.patch
  * grub2-arm64-bootaa64-fix-1.patch
  * grub2-arm64-bootaa64-fix-2.patch
  * grub2-arm64-Use-cpu-timer-for-timekeeping.patch
  * grub2-arm64-mknetdir-add-suport-for-arm64-efi.patch
  * 0001-unix-do-not-close-stdin-in-grub_passwd_get.patch
  * grub2-efi-check-path-non-null-before-grub_strrchr.patch
  * grub2-mkstandalone-out-of-bound-access-to-tar-header-.patch
  * grub2-efidisk-Respect-block_io_protocol-buffer-alignment.patch
  * grub2-arm64-Add-support-for-relocations-needed-for-linaro-.patch
  * grub2-XFS-Fix-wrong-alignment-treatment.patch
  * 0001-arm64-Move-firmware-fdt-search-into-global-function.patch
  * 0002-arm-efi-Use-fdt-from-firmware-when-available.patch
  * 0001-Fix-fwpath-in-efi-netboot.patch
  * grub2-net-icmp6-fix-no-respond-to-neighbor-solicit-message.patch
  * grub2-net-send-router-solicitation-for-ipv6-address-autoconf.patch
  * grub2-emu-hostfs-Drop-unnecessary-feature-test-macros.patch
- Rediff
  * use-grub2-as-a-package-name.patch
  * grub2-GRUB_CMDLINE_LINUX_RECOVERY-for-recovery-mode.patch
  * grub2-fix-menu-in-xen-host-server.patch
  * grub2-secureboot-chainloader.patch
  * grub2-s390x-02-kexec-module-added-to-emu.patch
  * grub2-s390x-04-grub2-install.patch
  * grub2-s390x-05-grub2-mkconfig.patch
  * grub2-mkconfig-aarch64.patch
  * grub2-btrfs-04-grub2-install.patch
  * grub2-btrfs-05-grub2-mkconfig.patch
  * grub2-btrfs-06-subvol-mount.patch
  * grub2-efi-xen-chainload.patch
  * grub2-ppc64-cas-reboot-support.patch
  * 0002-Add-Virtual-LAN-support.patch
  * grub2-emu-4-all.patch
  * grub2-mkconfig-arm.patch
- Renew
  * grub2-efi-HP-workaround.patch
- Replaced UEFI netboot patch
  * grub2-efinet-ipv6-dhcpv6.patch
  * grub2-efinet-ipv6-dhcpv6-use-mac-device.patch
  * grub2-bootp6-dns.patch
  * grub2-efinet-httpboot.patch
- New UEFI netboot patch
  * 0001-misc-fix-invalid-character-recongition-in-strto-l.patch
  * 0002-net-read-bracketed-ipv6-addrs-and-port-numbers.patch
  * 0003-bootp-New-net_bootp6-command.patch
  * 0004-efinet-UEFI-IPv6-PXE-support.patch
  * 0005-grub.texi-Add-net_bootp6-doument.patch
  * 0006-bootp-Add-processing-DHCPACK-packet-from-HTTP-Boot.patch
  * 0007-efinet-Setting-network-from-UEFI-device-path.patch
  * 0008-efinet-Setting-DNS-server-from-UEFI-protocol.patch
- Fix compilation with new glibc
  * fix-grub2-use-stat-instead-of-udevadm-for-partition-lookup-with-new-glibc.patch
- Remove unused patches
  * grub2-enable-theme-for-terminal-window.patch
  * 0001-script-provide-overridable-root-by-subvol.patch
  * 0002-script-create-menus-for-btrfs-snapshot.patch
- Drop workarounds for gdb_grub and grub.chrp, they are now installed under
  fixed name
- Do not patch docs/Makefile.in, it is regenerated anyway
  * rename-grub-info-file-to-grub2.patch
- Use grub_memset and grub_memcpy instead of memset and memcpy (caused errors due
  to compiler warning)
  * grub2-secureboot-add-linuxefi.patch
- Replace grub2-use-DejaVuSansMono-for-starfield-theme.patch with
  grub2-use-Unifont-for-starfield-theme-terminal.patch - use Unifont
  font for terminal window
- Remove patch-not-applied filter.
  * grub2.rpmlintrc
* Thu Feb  9 2017 mchang@suse.com
- Fix fwpath in efi netboot (fate#321993) (bsc#1022294)
  * 0001-Fix-fwpath-in-efi-netboot.patch
* Wed Feb  1 2017 agraf@suse.com
- Add support for BLT only EFI GOP adapters (FATE#322332)
  * grub2-efi-gop-add-blt.patch
* Fri Dec 16 2016 mchang@suse.com
- Ensure that the path start with / and has no // (bsc#1015599)
  * 0001-grub-core-kern-efi-efi.c-Ensure-that-the-result-star.patch
* Mon Nov 21 2016 mchang@suse.com
- grub2-xen-pv-firmware.cfg: insmod lvm module as it's not auto-loaded
  to support booting from lvm volume (bsc#1004324)
* Fri Nov  4 2016 matwey.kornilov@gmail.com
- Add grub2-mkconfig-arm.patch to fix broken config issues leading
  to unbootable system (bnc#1008568)
* Fri Nov  4 2016 matwey.kornilov@gmail.com
- Add 0001-arm64-Move-firmware-fdt-search-into-global-function.patch
  and 0002-arm-efi-Use-fdt-from-firmware-when-available.patch
  fix grub2 crash at armv7 systems (bnc#1008545):
* Fri Oct 21 2016 mchang@suse.com
- From Juergen Gross <jgross@suse.com>: grub-xen: support booting huge
  pv-domains (bsc#1004398) (bsc#899465)
  * 0001-xen-make-xen-loader-callable-multiple-times.patch
  * 0002-xen-avoid-memleaks-on-error.patch
  * 0003-xen-reduce-number-of-global-variables-in-xen-loader.patch
  * 0004-xen-add-elfnote.h-to-avoid-using-numbers-instead-of-.patch
  * 0005-xen-synchronize-xen-header.patch
  * 0006-xen-factor-out-p2m-list-allocation-into-separate-fun.patch
  * 0007-xen-factor-out-allocation-of-special-pages-into-sepa.patch
  * 0008-xen-factor-out-allocation-of-page-tables-into-separa.patch
  * 0009-xen-add-capability-to-load-initrd-outside-of-initial.patch
  * 0010-xen-modify-page-table-construction.patch
  * 0011-xen-add-capability-to-load-p2m-list-outside-of-kerne.patch
- Additional upstream patches
  * 0001-Import-xen-headers-directly-into-GRUB.patch
  * 0002-Adapt-build-system-to-use-imported-xen-headers.patch
  * 0003-xen-relocator-Use-local-symbol-to-ensure-that-code-i.patch
* Wed Oct 19 2016 mchang@suse.com
- Build arm-efi and arm64-efi for openSUSE (bsc#1004959)
  * refresh grub2-xfs-V5-filesystem-format-support.patch for upstream commit
  * add grub2-XFS-Fix-wrong-alignment-treatment.patch
  * add grub2-arm64-Add-support-for-relocations-needed-for-linaro-.patch
* Tue Oct 11 2016 dmueller@suse.com
- add support for netboot on arm64-efi platforms (bsc#998097)
  * grub2-arm64-mknetdir-add-suport-for-arm64-efi.patch
* Fri Sep 16 2016 mchang@suse.com
- Ignore partition tables on s390x. (bsc#935127)
  * grub2-s390x-08-workaround-part-to-disk.patch
* Wed Aug 31 2016 mchang@suse.com
- Drop ethernet-pad-to-minumum-size.patch (bsc#994497)
* Fri Aug 26 2016 mchang@suse.com
- Fix booting from network (on PowerPC) (bsc#994497)
  * 0007-arp-icmp-Fix-handling-in-case-of-oversized-or-invali.patch
  * ethernet-pad-to-minumum-size.patch
* Wed Aug 10 2016 mchang@suse.com
- Workaround default entry in snapshot menu (bsc#956046)
  * grub2-btrfs-08-workaround-snapshot-menu-default-entry.patch
- grub2.spec: Add true command to grub.efi (bsc#993274)
* Wed Aug  3 2016 mchang@suse.com
- grub.default: Empty GRUB_CMDLINE_LINUX_DEFAULT, the value will be fully
  taken from YaST settings. (bsc#989803)
* Mon Aug  1 2016 mchang@suse.com
- Cherrypick upstream patches for bug fixes (bsc#990086)
  * 0001-Initialized-initrd_ctx-so-we-don-t-free-a-random-poi.patch
  * 0002-grub-core-disk-lzopio.c-fix-double-free-in-error-pat.patch
  * 0003-fix-double-free-in-grub_net_recv_tcp_packet.patch
  * 0004-arm64-setjmp-Add-missing-move-for-arg1-0-case.patch
  * 0005-tftp-fix-memory-leaks-in-open.patch
  * 0006-Remove-the-variable-oldname-which-is-attempting-to-f.patch
- Upstream patch to fix GRUB2 clock too slow on RPI3 (bsc#990604)
  * grub2-arm64-Use-cpu-timer-for-timekeeping.patch
* Fri Jul 22 2016 dmueller@suse.com
- add grub2-mkstandalone-out-of-bound-access-to-tar-header-.patch,
  grub2-efi-check-path-non-null-before-grub_strrchr.patch
  grub2-efidisk-Respect-block_io_protocol-buffer-alignment.patch (bsc#990086)
* Fri Jul 22 2016 mchang@suse.com
- Add patches from Roberto Sassu <rsassu@suse.de>
- Fix grub2-10_linux-avoid-multi-device-root-kernel-argument.patch,
  device path is not tested if GRUB_DISABLE_LINUX_UUID="true"
  - added grub2-fix-multi-device-root-kernel-argument.patch
  (bsc#960776)
- grub2-zipl-setup: avoid multi-device root= kernel argument
  * added grub2-zipl-setup-fix-btrfs-multipledev.patch
  (bsc#960776)
- Add SUSE_REMOVE_LINUX_ROOT_PARAM configuration option
  to /etc/default/grub, to remove root= and rootflags= from the
  kernel command line in /boot/grub2/grub.cfg and /boot/zipl/config
  - added grub2-suse-remove-linux-root-param.patch
  (bsc#962585)
* Wed Jun 22 2016 mchang@suse.com
- Fix btrfs on BigEndian systems (bsc#980108) (bsc#933541)
  * modified grub2-btrfs-07-subvol-fallback.patch
- update grub2-once with patch from Björn Voigt - skip comments in
  /etc/sysconfig/bootloader (boo#963610)
- Fix "error: timeout: could not resolve hardware address.“ during network
  installation (bsc#980259)
  * added 0001-increase-network-try-interval-gradually.patch
  * refresh 0002-Add-Virtual-LAN-support.patch
* Wed Jun  8 2016 mchang@suse.com
- Fix error on encrypted lvm installation (bsc#981621)
  * added 0001-Fix-partmap-cryptodisk-and-abstraction-handling-in-g.patch
  * added 0002-disk-cryptodisk-Add-missing-error-check.patch
  * added 0003-crypto-restrict-cipher-block-size-to-power-of-2.patch
  * added 0004-cryptodisk-strip-parenthesis-from-backing-device-nam.patch
  * added 0005-cryptodisk-teach-grub_cryptodisk_insert-about-partit.patch
  * added 0006-do-not-emit-cryptomount-without-crypto-UUID.patch
* Mon Jun  6 2016 mchang@suse.com
- Fix grub2-editenv error on encrypted lvm installation (bsc#981621)
  * modified grub2-btrfs-workaround-grub2-once.patch
* Thu Jun  2 2016 mchang@suse.com
- Fix btrfs on BigEndian systems (bsc#980108) (bsc#933541)
  * modified grub2-btrfs-01-add-ability-to-boot-from-subvolumes.patch
  * modified grub2-btrfs-06-subvol-mount.patch
  * added grub2-getroot-fix-get-btrfs-fs-prefix-big-endian.patch
* Wed Jun  1 2016 rw@suse.com
- Examine variables from grub environment in 'grub2-once'. (fate#319632)
* Tue May 31 2016 mchang@suse.com
- Add systemd-sleep-plugin subpackage (bsc#981936)
  * added grub2-systemd-sleep.sh
- Fix build in factory with glibc 2.20
  * added grub2-emu-hostfs-Drop-unnecessary-feature-test-macros.patch
* Mon May 30 2016 rw@suse.com
- Extend config-file parsing in 'grub2-once'. (fate#319632)
- Build 'grub2-emu' wherever possible, to allow a better
  implementation of that feature.
  * grub2-emu-4-all.patch
- Add missing closing bracket in 'grub2-snapper-plugin.sh'.
* Fri May 27 2016 mchang@suse.com
- Add DNS support for UEFI HTTP Boot (fate#320129)
  * modified grub2-efinet-httpboot.patch
* Thu May 19 2016 agraf@suse.com
- Add patch to free memory on exit in efi environments (bsc#980739)
  * grub2-efi-Free-malloc-regions-on-exit.patch
* Mon May 16 2016 dvaleev@suse.com
- Fix btrfs endianess (bsc#980108)
  btrfs-fix_get_root_key_comparison_failures_due_to_endianness.patch
* Wed May 11 2016 dvaleev@suse.com
- Switch endiannes of stage1 on POWER (LE -> BE) (bsc#973651)
  - Dropped patches:
    grub2-ppc64-build-ppc64-32bit.patch
    grub2-ppc64le-01-Add-Little-Endian-support-for-Power64-to-the-build.patch
    grub2-ppc64le-02-Build-grub-as-O1-until-we-add-savegpr-and-restgpr-ro.patch
    grub2-ppc64le-03-disable-creation-of-vsx-and-altivec-instructions.patch
    grub2-ppc64le-04-powerpc64-LE-s-linker-knows-how-to-handle-the-undefi.patch
    grub2-ppc64le-05-grub-install-can-now-recognize-and-install-a-LE-grub.patch
    grub2-ppc64le-06-set-the-ABI-version-to-0x02-in-the-e_flag-of-the-PPC.patch
    grub2-ppc64le-07-Add-IEEE1275_ADDR-helper.patch
    grub2-ppc64le-08-Fix-some-more-warnings-when-casting.patch
    grub2-ppc64le-09-Add-powerpc64-types.patch
    grub2-ppc64le-10-powerpc64-is-not-necessarily-BigEndian-anymore.patch
    grub2-ppc64le-11-Fix-warnings-when-building-powerpc-linux-loader-64bi.patch
    grub2-ppc64le-12-GRUB_ELF_R_PPC_-processing-is-applicable-only-for-32.patch
    grub2-ppc64le-13-Fix-powerpc-setjmp-longjmp-64bit-issues.patch
    grub2-ppc64le-14-Add-powerpc64-ieee1275-trampoline.patch
    grub2-ppc64le-15-Add-64bit-support-to-powerpc-startup-code.patch
    grub2-ppc64le-16-Add-grub_dl_find_section_addr.patch
    grub2-ppc64le-17-Add-ppc64-relocations.patch
    grub2-ppc64le-18-ppc64-doesn-t-need-libgcc-routines.patch
    grub2-ppc64le-19-Use-FUNC_START-FUNC_END-for-powerpc-function-definit.patch
    grub2-ppc64le-20-.TOC.-symbol-is-special-in-ppc64le-.-It-maps-to-the-.patch
    grub2-ppc64le-21-the-.toc-section-in-powerpc64le-modules-are-sometime.patch
    grub2-ppc64le-22-all-parameter-to-firmware-calls-should-to-be-BigEndi.patch
    grub2-ppc64le-23-grub-segfaults-if-initrd-is-specified-before-specify.patch
    grub2-ppc64le-fix-64bit-trampoline-in-dyn-linker.patch
    grub2-ppc64le-timeout.patch
  - Added patches:
    biendian.patch
    libgcc-prereq.patch
    libgcc.patch
    ppc64_opt.patch
    ppc64le.patch
  - Refreshed patches:
    grub2-ppc64-cas-reboot-support.patch
    grub2-ppc64le-memory-map.patch
* Fri Apr 29 2016 agraf@suse.com
- Move from "--hidden" parameter in menuentry to new hiddenentry
  command (bsc#976836)
  * refreshed grub2-Add-hidden-menu-entries.patch
  * refreshed grub2-SUSE-Add-the-t-hotkey.patch
* Thu Apr 28 2016 agraf@suse.com
- Add support for "t" hotkey to switch to text mode (bsc#976836)
  * added grub2-SUSE-Add-the-t-hotkey.patch
- Fix default entry boot (bsc#977590)
  * refreshed grub2-Add-hidden-menu-entries.patch
* Tue Apr 26 2016 agraf@suse.com
- Add support for hidden menu entries (bsc#976836)
  * added grub2-Add-hidden-menu-entries.patch
* Mon Apr 25 2016 agraf@suse.com
- Correct the removable media file name on aarch64 (bsc#977031)
  * added grub2-arm64-bootaa64-fix-1.patch
  * added grub2-arm64-bootaa64-fix-2.patch
* Tue Apr 19 2016 mchang@suse.com
- Correct show user defined comments in menu for snapshots (bsc#956698)
  * modified grub2-snapper-plugin.sh
* Thu Apr 14 2016 mchang@suse.com
- Support HTTP Boot IPv4 and IPv6 (fate#320129)
  * added grub2-efinet-httpboot.patch
* Mon Mar 21 2016 mchang@suse.com
- Fix GRUB_DISABLE_LINUX_UUID to be ignore and also fallback kernel device
  won't be used if fs uuid not detected (bsc#971867)
  * added 0001-10_linux-Fix-grouping-of-tests-for-GRUB_DEVICE.patch
  * added 0002-20_linux_xen-fix-test-for-GRUB_DEVICE.patch
* Fri Mar 11 2016 mchang@suse.com
- Install and boot support for libnvdimm storage devices (fate#319861)
  * added 0001-efi-really-mark-memory-of-unknown-type-as-reserved.patch
  * added 0002-Translate-UEFI-persistent-memory-type.patch
  * added 0003-lsefimmap-support-persistent-memory-and-other-UEFI-2.patch
* Wed Mar  2 2016 mchang@suse.com
- fix attempt to seek outside of the file error when parsing xen ELF notes
  (bsc#968721)
  * added grub2-xen-fix-bzImage-payload-length.patch
* Wed Feb  3 2016 mchang@suse.com
- Add config option to set efi xen loader command line option (bsc#957383)
  * added grub2-efi-xen-cmdline.patch
- Fix guest unable to boot if rootfs is on btrfs and spans multiple disks
  (bsc#960776)
  * added grub2-10_linux-avoid-multi-device-root-kernel-argument.patch
- Support booting installer media as PV DomU (boo#926795)
  * added grub2-xen-pv-firmware.cfg from Olaf Hering <ohering@suse.com>
- Backport upstream patches for HyperV gen2 TSC timer calbration without
  RTC (bsc#904647) (bsc#962182)
  * added 0001-grub-core-kern-i386-tsc.c-calibrate_tsc-Ensure-that.patch
  * added 0002-i386-tsc-Fix-unused-function-warning-on-xen.patch
  * added 0003-acpi-do-not-skip-BIOS-scan-if-EBDA-length-is-zero.patch
  * added 0004-tsc-Use-alternative-delay-sources-whenever-appropria.patch
  * added 0005-i386-fix-TSC-calibration-using-PIT.patch
* Tue Dec  1 2015 mchang@suse.com
- Check msdos header to find PE file header (bsc#954126)
  * modified grub2-efi-chainload-harder.patch:
- Use dirname for copying xen kernel and initrd to esp (bsc#955493)
  * modified grub2-efi-xen-chainload.patch
- drop grub2-fix-Grub2-with-SUSE-Xen-package-install.patch (bsc#774666)
* Tue Dec  1 2015 arvidjaar@gmail.com
- Add 0001-unix-do-not-close-stdin-in-grub_passwd_get.patch
  Fix reading password by grub2-mkpasswd-pbdk2 without controlling
  tty, e.g. when called from Xfce menu (boo#954519)
- add luks, gcry_rijndael, gcry_sha1 to signed EFI image to support
  LUKS partition in default setup (boo#917427) (boo#955609)
* Mon Nov 30 2015 mchang@suse.com
- CVE-2015-8370: grub2: overflows in grub_password_get and grub_user_get
  (bsc#956631)
  * add fix-overflows-in-grub_password_get-and-grub_user_get.patch
* Mon Nov 30 2015 mchang@suse.com
- Add btrfs default subvol /.snapshots/1/snapshot into pvgrub2's
  config search path list (bsc#952539)
* Tue Nov 17 2015 mchang@suse.com
- Fix wrong escape sequence in previous commit (bsc#955115)
  * modified grub2-snapper-plugin.sh
* Mon Nov 16 2015 mchang@suse.com
- Fix snapshot booting on s390x (bsc#955115)
  * modified grub2-snapper-plugin.sh
* Fri Nov  6 2015 mchang@suse.com
- Fallback to old subvol name scheme to support old snapshot config
  (bsc#953538)
  * added grub2-btrfs-07-subvol-fallback.patch
* Thu Oct 29 2015 mchang@suse.com
- Add missing quoting for linuxefi (bsc#951962)
  * modified grub2-secureboot-use-linuxefi-on-uefi.patch
  * refreshed grub2-secureboot-provide-linuxefi-config.patch
* Wed Oct  7 2015 mchang@suse.com
- Upstream patches for fixing file descriptor leakage (bsc#943784)
  * added 0001-unix-password-Fix-file-descriptor-leak.patch
  * added 0002-linux-getroot-fix-descriptor-leak.patch
  * added 0003-util-grub-mount-fix-descriptor-leak.patch
  * added 0004-linux-ofpath-fix-descriptor-leak.patch
  * added 0005-grub-fstest-fix-descriptor-leak.patch
* Mon Oct  5 2015 mchang@suse.com
- evaluate the menu entry's title string by printf (bsc#946993)
  * modified grub2-once
* Wed Sep 23 2015 dmueller@suse.com
- add 0001-efinet-Check-for-immediate-completition.patch,
  0001-efinet-enable-hardware-filters-when-opening-interfac.patch,
  grub2-arm64-efinet-handle-get_status-on-buggy-firmware-properly.patch
  (bsc#947203)
* Fri Sep 18 2015 rw@suse.com
- Force '/usr' to read-only before calling kexec. (bsc#932951)
  * modified grub2-s390x-04-grub2-install.patch
- Require 'kexec-tools' for System z. (bsc#944358)
  * modified grub2.spec
* Fri Sep 18 2015 mchang@suse.com
- Add btrfs default subvol @/.snapshots/1/snapshot in config search
  list for system installed to snapshot. (bsc#946148)
  * modified grub2.spec
* Thu Sep 17 2015 mchang@suse.com
- Do not use shim lock protocol for reading pe header, it won't be
  available when secure boot disabled (bsc#943380)
- Make firmware flaw condition be more precisely detected and add
  debug message for the case
  * modified grub2-efi-chainload-harder.patch:
* Tue Sep 15 2015 jjolly@suse.com
- Added grub2-s390x-07-add-image-param-for-zipl-setup.patch
  * Add --image switch to force zipl update to specific kernel
    (bsc#928131)
* Wed Sep  9 2015 mchang@suse.com
- Set default GRUB_DISTRIBUTOR from /etc/os-release if it is empty
  or not set by user (bsc#942519)
  * added grub2-default-distributor.patch
  * modified grub.default
* Tue Jul  7 2015 mchang@suse.com
- Replace 12.1 with 12 SP1 for the list of snapshots (bsc#934252)
  * modified grub2-snapper-plugin.sh
* Tue Jun 30 2015 dmueller@suse.com
- add grub2-arm64-Reduce-timer-event-frequency-by-10.patch,
  grub2-arm64-set-correct-length.patch,
  grub2-mkconfig-aarch64.patch (fate#318444)
* Tue Jun 16 2015 mchang@suse.com
- Allow to execute menuentry unrestricted as default (fate#318574)
  * added grub2-menu-unrestricted.patch
* Fri Jun 12 2015 mchang@suse.com
- Show user defined comments in grub2 menu for snapshots (fate#318101)
  * modified grub2-snapper-plugin.sh
* Tue Jun  9 2015 mchang@suse.com
- If we have a post entry and the description field is empty, we should use the
  "Pre" number and add that description to the post entry. (fate#317972)
* Thu Jun  4 2015 mchang@suse.com
- Fix install into snapper controlled btrfs subvolume and can't
  load grub modules from separate subvolume (fate#318392)
  * added grub2-btrfs-06-subvol-mount.patch
  * grub2-snapper-plugin.sh: use absolute subvol name
* Wed Jun  3 2015 agraf@suse.com
- Fix license for setjmp module
  * added grub2-arm64-setjmp-Add-missing-license-macro.patch
* Sun May 10 2015 arvidjaar@gmail.com
- replace grub2-efinet-reopen-SNP-protocol-for-exclusive-use-by-grub.patch
  with upstream version:
  * 0001-efidisk-move-device-path-helpers-in-core-for-efinet.patch
  * 0002-efinet-skip-virtual-IPv4-and-IPv6-devices-when-enume.patch
  * 0003-efinet-open-Simple-Network-Protocol-exclusively.patch
  Fixes EFI network boot in some QEMU configurations.
* Mon Mar  2 2015 mchang@suse.com
- UEFI IPv6 PXE booting support (bsc#894178)
- added patches
  * grub2-net-send-router-solicitation-for-ipv6-address-autoconf.patch
  * grub2-net-icmp6-fix-no-respond-to-neighbor-solicit-message.patch
  * grub2-efinet-ipv6-dhcpv6.patch
  * grub2-efinet-ipv6-dhcpv6-use-mac-device.patch
  * grub2-bootp6-dns.patch
* Wed Feb 11 2015 rw@suse.com
- grub2-s390x-04-grub2-install.patch:
  * streamline boot to grub menu.  (bsc#898198)
- grub2-s390x-06-loadparm.patch:
  * ignore case and fix transliteration of parameter.  (bsc#891946)
- grub2-once:
  * fix submenu handling and ignore comments.
* Fri Jan 30 2015 dvaleev@suse.com
- Fix CAS reboot on PowerPC (bsc#913667)
  - grub2-ppc64-cas-reboot-support.patch
* Mon Jan 26 2015 mchang@suse.com
- update grub2-snapper-plugin.sh:
  * cleanup grub-snapshot.cfg not referring to any snapshot
    (boo#909359, bsc#914514)
  * replace echo -e with printf to fix script bashism
* Mon Oct 20 2014 rw@suse.de
- grub2-s390x-06-loadparm.patch,
  grub2-commands-introduce-read_file-subcommand.patch:
  * allow s390x to telecontrol grub2.  (bsc#891946, bsc#892852)
- grub2-once:
  * add '--enum' option to enumerate boot-entries in a way
    actually understood by 'grub2'.  (bsc#892852, bsc#892811)
- grub2-btrfs-05-grub2-mkconfig.patch:
  * refresh
  * plus fix for 'rollback' hint (while at it).  (bsc#901487)
- grub2-s390x-05-grub2-mkconfig.patch,
  grub2-btrfs-workaround-grub2-once.patch;
  * refresh.
* Fri Sep 26 2014 mchang@suse.com
- do not pass root= when root is on nfs (bnc#894374)
- modified patches:
  * grub2-pass-corret-root-for-nfsroot.patch
  * grub2-secureboot-provide-linuxefi-config.patch
  * grub2-secureboot-use-linuxefi-on-uefi.patch
* Fri Sep 19 2014 mchang@suse.com
- do not use environment block in btrfs for s390x (bnc#892358)
  * refresh grub2-btrfs-workaround-grub2-once.patch
* Mon Sep 15 2014 mchang@suse.com
- fix parsing /proc/self/mountinfo (bnc#896186)
  * refresh grub2-pass-corret-root-for-nfsroot.patch
- fix xen pvops kernel not appear on menu (bnc#895286)
  * refresh grub2-fix-menu-in-xen-host-server.patch
- fix extraneous comma in printf shell command (bnc#895884)
  * refresh grub2-btrfs-04-grub2-install.patch
* Fri Sep  5 2014 mchang@suse.com
- add nfs or nfs4 to root= for root on nfs (bnc#894374)
- modified patches:
  * grub2-pass-corret-root-for-nfsroot.patch
* Wed Sep  3 2014 mchang@suse.com
- workaround grub2-once (bnc#892358)
- use unused sectors in btrfs as environment block for holding the
  next_entry variable
  * added grub2-btrfs-workaround-grub2-once.patch
  * refresh grub2-btrfs-05-grub2-mkconfig.patch
- running a service during boot to unset next_entry, this is workaround
  for lvm, md and s390
  * updated grub2-once
  * added grub2-once.service
* Mon Sep  1 2014 mchang@suse.com
- add grub2-once.service
* Fri Aug 29 2014 mchang@suse.com
- add grub2-once-workaround.patch
* Wed Aug 27 2014 schwab@suse.de
- Enable building on aarch64
- aarch64-reloc.patch: strip .eh_frame section from arm64-efi kernel
* Fri Aug 22 2014 rw@suse.com
- grub2-s390x-04-grub2-install.patch:
  * fix removal of obsolete files.  (bnc#892810)
* Fri Aug 22 2014 rw@suse.com
- grub2-s390x-04-grub2-install.patch:
  * add support for legacy '/boot'.  (bnc#873951, bnc#892088)
* Fri Aug 22 2014 rw@suse.com
- grub2-s390x-04-grub2-install.patch:
  * make snapshots submenu available after rollback.  (bnc#892014)
* Thu Aug 14 2014 mchang@suse.com
- grub2-btrfs-fix-incorrect-address-reference.patch
  * Fix incorrect address reference in GRUB_BTRFS_EXTENT_REGULAR
    range check (bnc#869748)
* Mon Aug 11 2014 dvaleev@suse.com
- Fix the 64-bit trampoline code in dynamic linker (bnc#890999)
  grub2-ppc64le-fix-64bit-trampoline-in-dyn-linker.patch
* Fri Aug  1 2014 mchang@suse.com
- grub2-vbe-blacklist-preferred-1440x900x32.patch
  * Blacklist preferred resolution 1440x900x32 which is broken on
    many Thinkpads (bnc#888727)
* Thu Jul 31 2014 rw@suse.com
- grub2-s390x-04-grub2-install.patch:
  * don't set 'rootflags' for zIPL.  (bnc#889572)
* Wed Jul 30 2014 rw@suse.com
- grub2-s390x-04-grub2-install.patch:
  * correctly set 'rootflags' for zIPL.  (#bnc#889562, bnc#889572)
* Wed Jul 30 2014 rw@suse.com
- grub2-efi-chainload-harder.patch:
  * allow XEN to be chain-loaded despite firmware flaws.  (bnc#887793)
* Tue Jul 29 2014 tiwai@suse.de
- Prefer a higher resolution in efi_gop driver if the mode taking
  over is too small like 640x480 (bnc#887972):
  grub2-efi_gop-avoid-low-resolution.patch
* Mon Jul 28 2014 rw@suse.com
- enhance grub2-snapper-plugin.sh with hotkeys for s390.
- grub2-btrfs-05-grub2-mkconfig.patch:
  * add conditional pseudo sub-menu to highlight snapshot booting.
- grub2-s390x-03-output-7-bit-ascii.patch:
  * support hotkeys on all line-mode terminals, not only 3215.
- grub2-s390x-05-grub2-mkconfig.patch:
  * remove 's' from possible hot-keys for "bootable snapshots".
  (bnc#885668)
- grub2-s390x-04-grub2-install.patch:
  * grub2-zipl-setup: honor GRUB_DISABLE_LINUX_UUID.
  (bnc#885854)
* Mon Jul 28 2014 dvaleev@suse.com
- update grub2-ppc64le-memory-map.patch to match the one submitted
  upstream
  (http://lists.gnu.org/archive/html/grub-devel/2014-07/msg00033.html)
* Mon Jul 21 2014 mchang@suse.com
- add warning in grubenv file about do not edit it other than by
  grub2-editenv (bnc#887008)
- added grub2-editenv-add-warning-message.patch
* Fri Jul  4 2014 mchang@suse.com
- fix broken graphics with efifb on QEMU/KVM and nomodeset (bnc#884558)
- added patch:grub2-efi-disable-video-cirrus-and-bochus.patch
* Thu Jul  3 2014 dvaleev@suse.com
- Track occupied memory by GRUB2 so it can be released on exit
  bnc#885026 (grub2-ppc64le-memory-map.patch)
* Thu Jul  3 2014 mchang@suse.com
- change description of bootable snapshot to start bootloader from
  a read-only snapshot and exclude read-write snapshots from the list
  (bnc#878528)
- refresh grub2-snapper-plugin.sh
* Thu Jul  3 2014 mchang@suse.com
- add grub.xen config searching path on boot partition (bnc#884828)
- add linux16 and initrd16 to grub.xen (bnc#884830)
- added patches:
  * grub2-xen-linux16.patch
* Mon Jun 30 2014 dvaleev@suse.com
- VLAN tag support (FATE#315753)
  0001-Add-bootargs-parser-for-open-firmware.patch
  0002-Add-Virtual-LAN-support.patch
* Fri Jun 20 2014 jeffm@suse.com
- grub2: use stat instead of udevadm for partition lookup (bnc#883635)
  * Added grub2-use-stat-instead-of-udevadm-for-partition-lookup.patch
* Mon Jun 16 2014 rw@suse.com
- grub2-s390x-04-grub2-install.patch:
  * fix dracut module for grub2.  (bnc#879136)
- grub2-s390x-03-output-7-bit-ascii.patch:
  * improve recognition of control sequences in line-mode.
* Fri Jun 13 2014 jack@suse.cz
- xfs V5 superblock support (bnc#880166)
- added patches:
  * grub2-xfs-Add-helper-for-inode-size.patch
  * grub2-xfs-Fix-termination-loop-for-directory-iteration.patch
  * grub2-xfs-Convert-inode-numbers-to-cpu-endianity-immediate.patch
  * grub2-xfs-V5-filesystem-format-support.patch
* Tue Jun  3 2014 dvaleev@suse.com
- Disable video support on Power (bnc#877142)
- Move grub2-netboot-hang.patch out from ppc patches to generic.
  The patch is valid for all architecures.
- added patches:
  * grub2-ppc64le-disable-video.patch
* Mon Jun  2 2014 rw@suse.com
- grub2-efi-xen-chainload.patch:
  * use only one config file per XEN hypervisor version containing
    sections for different kernels.
  * remove previously installed files from ESP.
  * avoid useless duplicates for sym-linked hypervisors.
- grub2-efi-chainloader-root.patch:
  * use device part of chainloader target, if present.  (bnc#871857)
* Tue May 27 2014 mchang@suse.com
- grub2-setup-try-fs-embed-if-mbr-gap-too-small.patch
  * try to embed on file system when mbr gap too small (bnc#879271)
* Wed May 21 2014 rw@suse.com
- grub2-efi-xen-chainload.patch:
  * add missing whitespace.  (bnc#879148)
* Mon May 19 2014 rw@suse.com
- grub2-efi-xen-chainload.patch:
  * use chainloader to boot xen.efi under UEFI.  (bnc#871857)
* Fri May 16 2014 rw@suse.com
- remove architecture-specific boot directory for s390x-emu
  in favor of 's390-tools'.
* Thu May 15 2014 rw@suse.com
- grub2-s390x-04-grub2-install.patch:
  * use 'showconsole' to determine console device.  (bnc#876743)
- grub2-s390x-03-output-7-bit-ascii.patch:
  * fix detection of terminal type now accessible.
* Thu May 15 2014 mchang@suse.com
- s390x snapper rollback support
  * refresh grub2-snapper-plugin.sh
  * refresh grub2-btrfs-05-grub2-mkconfig.patch
- create only hypervisor pointed by /boot/xen.gz symlink (bnc#877040)
  * refresh grub2-fix-Grub2-with-SUSE-Xen-package-install.patch
  * refresh grub2-fix-menu-in-xen-host-server.patch
* Wed Apr 30 2014 rw@suse.com
- package architecture-specific boot directory for s390x-emu. (bnc#873951)
- grub2-s390x-04-grub2-install.patch:
  * support 'xz' initrd compression.  (bnc#874155)
* Wed Apr 30 2014 mchang@suse.com
- refresh grub2-snapper-plugin.sh, suppress "XPath set is empty"
  warning message (bnc#866944)
* Mon Apr 28 2014 dvaleev@suse.com
- grub can busy-loop and hang while network booting, when the network
  has some fair amount of acitivity. This is because grub's net module
  sniffs the network for packets, and busy-loops in receive_packets()
  till it finds network packet of type ip or ipv6.
  During this period grub will not respond to any user input, thus
  hanging up the system. (bnc#870613)
  grub2-netboot-hang.patch fixes it
* Mon Apr 21 2014 mchang@suse.com
- refresh grub2-linux.patch
  * fix xen and native entries differ in grub.cfg (bnc#872014)
- add grub2-getroot-support-NVMe-device-names.patch
  * fix booting from NVMe device enters GRUB rescue (bnc#873132)
- add grub2-getroot-treat-mdadm-ddf-as-simple-device.patch
  * fix grub2-install error on ddf md device (bnc#872360)
* Mon Apr 14 2014 rw@suse.com
- grub2-efi-HP-workaround.patch:
  * try to read config from all-uppercase prefix as last resort.
    (bnc#872503)
* Fri Apr 11 2014 mchang@suse.com
- export btrfs_relative_path correctly
  * refresh grub2-btrfs-03-follow_default.patch
  * refresh grub2-btrfs-04-grub2-install.patch
* Thu Apr 10 2014 dvaleev@suse.com
- Add powerpc-utils to grub2-powerpc-ieee1275's requires
* Thu Apr 10 2014 mchang@suse.com
- add grub2-efinet-reopen-SNP-protocol-for-exclusive-use-by-grub.patch
  (bnc#871555)
- add grub2-xen-legacy-config-device-name.patch (bnc#863821)
* Wed Apr  9 2014 mchang@suse.com
- snapper rollback support, improve the bootloader installation
  without wrapper script, reduce the detours on different architecture
  and rename related patches properly
  * rename 0002-btrfs-add-ability-to-boot-from-subvolumes.patch to
  grub2-btrfs-01-add-ability-to-boot-from-subvolumes.patch
  * rename 0004-btrfs-export-subvolume-envvars.patch to
  grub2-btrfs-02-export-subvolume-envvars.patch
  * rename SUSE_BTRFS_SNAPSHOT_BOOTING.patch to
  grub2-btrfs-05-grub2-mkconfig.patch
  * rename btrfs_follow_default.patch to
  grub2-btrfs-03-follow_default.patch
  * add grub2-btrfs-04-grub2-install.patch
  * delete 0003-cmdline-add-envvar-loader_cmdline_append.patch
  * remove suse_btrfs_grub2_install.sh
  * refresh grub2-snapper-plugin.sh, export extra_cmdline
* Mon Apr  7 2014 dvaleev@suse.com
- Fix grub2 timeout stop counting on ppc64le (bnc#869166)
- added patches:
  * grub2-timout.patch
* Tue Apr  1 2014 mchang@suse.com
- add Recommends to libburnia-tools (bnc#812681)
* Mon Mar 31 2014 rw@suse.com
- Document peculiarities of s390 terminals in 'README.ibm3215'.
- grub2-s390x-02-kexec-module-added-to-emu.patch:
  * Improve exit message for dry-run (and cleanup).
- grub2-s390x-03-output-7-bit-ascii.patch:
  * Fix handling of '^C' and solitary '^'.  (bnc#867258)
  * Exit properly with mode-reset.
- grub2-s390x-04-grub2-install.patch:
  * Install helper script as '/usr/sbin/grub2-zipl-setup'.
  * Console mode may be controlled from config file.  (bnc#868909)
- grub2-s390x-05-grub2-mkconfig.patch:
  * Add 'conmode=' to command-line, if configured.  (bnc#868909)
* Mon Mar 31 2014 mchang@suse.com
- snapper rollback support (fate#317062)
  * add btrfs_follow_default.patch
  * add suse_btrfs_grub2_install.sh
  * add 80_suse_btrfs_snapshot
  * add SUSE_BTRFS_SNAPSHOT_BOOTING.patch
  * refresh grub2-snapper-plugin.sh
* Fri Mar 28 2014 mchang@suse.com
- add grub2-x86_64-xen subpackage (bnc#863821)
* Wed Mar 26 2014 dvaleev@suse.com
- ieee1275: check for IBM pseries emulated machine (bnc#869964)
- added patches:
  * grub2-ppc64-build-ppc64-32bit.patch
* Wed Mar 26 2014 dvaleev@suse.com
- Build ppc64 as 32bit
- added patches:
  * grub2-ppc64-build-ppc64-32bit.patch
* Wed Mar 26 2014 dvaleev@suse.com
- Rename PowerPC patches so it will have architecture in it's name
- added patches:
  * grub2-ppc64le-01-Add-Little-Endian-support-for-Power64-to-the-build.patch
  * grub2-ppc64le-02-Build-grub-as-O1-until-we-add-savegpr-and-restgpr-ro.patch
  * grub2-ppc64le-03-disable-creation-of-vsx-and-altivec-instructions.patch
  * grub2-ppc64le-04-powerpc64-LE-s-linker-knows-how-to-handle-the-undefi.patch
  * grub2-ppc64le-05-grub-install-can-now-recognize-and-install-a-LE-grub.patch
  * grub2-ppc64le-06-set-the-ABI-version-to-0x02-in-the-e_flag-of-the-PPC.patch
  * grub2-ppc64le-07-Add-IEEE1275_ADDR-helper.patch
  * grub2-ppc64le-08-Fix-some-more-warnings-when-casting.patch
  * grub2-ppc64le-09-Add-powerpc64-types.patch
  * grub2-ppc64le-10-powerpc64-is-not-necessarily-BigEndian-anymore.patch
  * grub2-ppc64le-11-Fix-warnings-when-building-powerpc-linux-loader-64bi.patch
  * grub2-ppc64le-12-GRUB_ELF_R_PPC_-processing-is-applicable-only-for-32.patch
  * grub2-ppc64le-13-Fix-powerpc-setjmp-longjmp-64bit-issues.patch
  * grub2-ppc64le-14-Add-powerpc64-ieee1275-trampoline.patch
  * grub2-ppc64le-15-Add-64bit-support-to-powerpc-startup-code.patch
  * grub2-ppc64le-16-Add-grub_dl_find_section_addr.patch
  * grub2-ppc64le-17-Add-ppc64-relocations.patch
  * grub2-ppc64le-18-ppc64-doesn-t-need-libgcc-routines.patch
  * grub2-ppc64le-19-Use-FUNC_START-FUNC_END-for-powerpc-function-definit.patch
  * grub2-ppc64le-20-.TOC.-symbol-is-special-in-ppc64le-.-It-maps-to-the-.patch
  * grub2-ppc64le-21-the-.toc-section-in-powerpc64le-modules-are-sometime.patch
  * grub2-ppc64le-22-all-parameter-to-firmware-calls-should-to-be-BigEndi.patch
  * grub2-ppc64le-23-grub-segfaults-if-initrd-is-specified-before-specify.patch
- removed patches:
  * 0001-Add-Little-Endian-support-for-Power64-to-the-build.patch
  * 0002-Build-grub-as-O1-until-we-add-savegpr-and-restgpr-ro.patch
  * 0003-disable-creation-of-vsx-and-altivec-instructions.patch
  * 0004-powerpc64-LE-s-linker-knows-how-to-handle-the-undefi.patch
  * 0005-grub-install-can-now-recognize-and-install-a-LE-grub.patch
  * 0006-set-the-ABI-version-to-0x02-in-the-e_flag-of-the-PPC.patch
  * 0007-Add-IEEE1275_ADDR-helper.patch
  * 0008-Fix-some-more-warnings-when-casting.patch
  * 0009-Add-powerpc64-types.patch
  * 0010-powerpc64-is-not-necessarily-BigEndian-anymore.patch
  * 0011-Fix-warnings-when-building-powerpc-linux-loader-64bi.patch
  * 0012-GRUB_ELF_R_PPC_-processing-is-applicable-only-for-32.patch
  * 0013-Fix-powerpc-setjmp-longjmp-64bit-issues.patch
  * 0014-Add-powerpc64-ieee1275-trampoline.patch
  * 0015-Add-64bit-support-to-powerpc-startup-code.patch
  * 0016-Add-grub_dl_find_section_addr.patch
  * 0017-Add-ppc64-relocations.patch
  * 0018-ppc64-doesn-t-need-libgcc-routines.patch
  * 0019-Use-FUNC_START-FUNC_END-for-powerpc-function-definit.patch
  * 0020-.TOC.-symbol-is-special-in-ppc64le-.-It-maps-to-the-.patch
  * 0020-all-parameter-to-firmware-calls-should-to-be-BigEndi.patch
  * 0021-the-.toc-section-in-powerpc64le-modules-are-sometime.patch
  * 0022-all-parameter-to-firmware-calls-should-to-be-BigEndi.patch
  * 0023-grub-segfaults-if-initrd-is-specified-before-specify.patch
* Wed Mar 26 2014 dvaleev@suse.com
- Require powerpc-utils for grub2-powerpc-ieee1275 package
  (grub2-install calls nvram from it)
* Tue Mar 18 2014 rw@suse.com
- grub2-s390x-03-output-7-bit-ascii.patch:
  * first usable interface on 3215 from initrd.  (bnc#867258)
* Tue Mar 18 2014 rw@suse.com
- reflect s390x-specifics in '/etc/default/grub'.  (fate#314213)
- grub2-s390x-02-kexec-module-added-to-emu.patch:
  * boot-attempts are final, except if 'kexec -l' fails.
  * try to restore terminal on exit (via grub_reboot()).
- grub2-s390x-03-output-7-bit-ascii.patch:
  * use less CPU cycles waiting for user.  (bnc#868650)
  * first usable interface on 3215.  (bnc#867258)
  * strip newlines on input for 3270 and 3215.
- grub2-s390x-04-grub2-install.patch:
  * append 'quiet splash=silent' for 'initgrub'-boot.
  * properly check for dracut script during 'grub2-install'.
* Wed Mar  5 2014 rw@suse.com
- grub2-s390x-04-grub2-install.patch:
  * refresh initrd by default, prefer running kernel and
    re-zipl despite minor issues.  (bnc#866867, fate#314213)
* Tue Mar  4 2014 rw@suse.com
- grub2-s390x-03-output-7-bit-ascii.patch:
  * force terminfo to ASCII.
- grub2-s390x-04-grub2-install.patch:
  * try harder to find root filesystem (incl. subvol-handling)
  * read /etc/sysconfig/bootloader as final fallback
- grub2-s390x-05-grub2-mkconfig.patch:
  * omit subvolume-prefix for platform "emu"
- refresh 0001-script-provide-overridable-root-by-subvol.patch.
* Mon Mar  3 2014 rw@suse.com
- build grub2-emu for s390 non-static, with device-mapper support,
  but without grub2-mount and start to move arch-specific parts
  to appropriate sub-packages.  (fate#314213)
- grub2-s390x-02-kexec-module-added-to-emu.patch:
  * introduce '--kexec/-X' to grub2-emu command-line to prevent
    inadvertent system interruption.
  * first give 'systemctl kexec' a chance on '-X' and
    fall back to 'kexec -e' only '-X' is present twice.
- disable grub2-s390x-03-output-7-bit-ascii.patch for now.
- grub2-s390x-04-grub2-install.patch:
  * add 's390x-emu' platform-support to grub2-install.
  * provide all parts to zIPL into a grub2-emu shell,
    including 'zipl.conf'-generator and 'dracut'-scriptlets.
- grub2-s390x-05-grub2-mkconfig.patch:
  * allow 's390x' "image"-files to '10_linux' kernel enumeration.
- refresh 0001-script-provide-overridable-root-by-subvol.patch to
  resolve conflict in util/grub.d/10_linux.in.
- refresh powerpc64le-as-powerpc.patch to resolve conflict
  in configure.ac.
* Mon Mar  3 2014 dvaleev@suse.com
- Refresh PowerLE patches
- added patches:
  * 0001-Add-Little-Endian-support-for-Power64-to-the-build.patch
  * 0003-disable-creation-of-vsx-and-altivec-instructions.patch
  * 0004-powerpc64-LE-s-linker-knows-how-to-handle-the-undefi.patch
  * 0005-grub-install-can-now-recognize-and-install-a-LE-grub.patch
  * 0006-set-the-ABI-version-to-0x02-in-the-e_flag-of-the-PPC.patch
  * 0007-Add-IEEE1275_ADDR-helper.patch
  * 0008-Fix-some-more-warnings-when-casting.patch
  * 0009-Add-powerpc64-types.patch
  * 0010-powerpc64-is-not-necessarily-BigEndian-anymore.patch
  * 0011-Fix-warnings-when-building-powerpc-linux-loader-64bi.patch
  * 0012-GRUB_ELF_R_PPC_-processing-is-applicable-only-for-32.patch
  * 0013-Fix-powerpc-setjmp-longjmp-64bit-issues.patch
  * 0014-Add-powerpc64-ieee1275-trampoline.patch
  * 0015-Add-64bit-support-to-powerpc-startup-code.patch
  * 0016-Add-grub_dl_find_section_addr.patch
  * 0017-Add-ppc64-relocations.patch
  * 0018-ppc64-doesn-t-need-libgcc-routines.patch
  * 0019-Use-FUNC_START-FUNC_END-for-powerpc-function-definit.patch
  * 0020-.TOC.-symbol-is-special-in-ppc64le-.-It-maps-to-the-.patch
  * 0021-the-.toc-section-in-powerpc64le-modules-are-sometime.patch
  * 0022-all-parameter-to-firmware-calls-should-to-be-BigEndi.patch
  * 0023-grub-segfaults-if-initrd-is-specified-before-specify.patch
- removed patches:
  * 0001-Add-a-new-architecture-to-the-build-process.patch
  * 0003-powerpc64-LE-s-linker-knows-how-to-handle-the-undefi.patch
  * 0004-grub-install-can-now-recognize-and-install-a-LE-grub.patch
  * 0005-set-the-ABI-version-to-0x02-in-the-e_flag-of-the-PPC.patch
  * 0006-Add-IEEE1275_ADDR-helper.patch
  * 0007-Fix-some-more-warnings-when-casting.patch
  * 0008-Add-powerpc64-types.patch
  * 0009-Fix-warnings-when-building-powerpc-linux-loader-64bi.patch
  * 0010-GRUB_ELF_R_PPC_-processing-is-applicable-only-for-32.patch
  * 0011-Fix-powerpc-setjmp-longjmp-64bit-issues.patch
  * 0012-Add-powerpc64-ieee1275-trampoline.patch
  * 0013-Add-64bit-support-to-powerpc-startup-code.patch
  * 0014-Add-grub_dl_find_section_addr.patch
  * 0015-Add-ppc64-relocations.patch
  * 0016-ppc64-doesn-t-need-libgcc-routines.patch
  * 0017-Use-FUNC_START-FUNC_END-for-powerpc-function-definit.patch
  * 0018-.TOC.-symbol-is-special-in-ppc64le-.-It-maps-to-the-.patch
  * 0019-the-.toc-section-in-powerpc64le-modules-are-sometime.patch
  * 0021-powerpc64-is-not-necessarily-BigEndian-anymore.patch
  * 0022-grub-segfaults-if-initrd-is-specified-before-specify.patch
  * 0023-Power7-cannot-handle-VSX-instructions-correctly.-It-.patch
  * powerpc-novsx-noaltivec.patch
  * powerpc64le-as-powerpc.patch
- modified patches:
  * 0002-Build-grub-as-O1-until-we-add-savegpr-and-restgpr-ro.patch
* Fri Feb 28 2014 dvaleev@suse.com
- build with -mno-vsx and -mno-altivec on powerpc
- added patches:
  * powerpc-novsx-noaltivec.patch
* Thu Feb 27 2014 dvaleev@suse.com
- The following patches enable grub to support
  64bit Little Endian Power architecture. (bnc#865913)
  Anton Blanchard (12):
  Add IEEE1275_ADDR helper
  Fix some more warnings when casting.
  Add powerpc64 types
  Fix warnings when building powerpc linux loader 64bit
  Fix powerpc setjmp/longjmp 64bit issues
  Add powerpc64 ieee1275 trampoline
  Add 64bit support to powerpc startup code
  Add grub_dl_find_section_addr
  Add ppc64 relocations
  ppc64 doesn't need libgcc routines
  Use FUNC_START/FUNC_END for powerpc function definitions
  powerpc64 is not necessarily BigEndian anymore! :)
  Ram Pai (11):
  Add a new architecture to the build process
  Build grub as O1 until we add savegpr and restgpr routines
  powerpc64 LE's linker knows how to handle the undefined symbol .TOC.
    in grub modules. So just ignore that symbol during build.
  grub-install can now recognize and install a LE grub boot loader
  set the ABI version to 0x02 in the e_flag of the PPC64LE ELF image.
  GRUB_ELF_R_PPC_* processing is applicable only for 32 bit bootloader.
  .TOC. symbol is special in ppc64le . It maps to the address of the
    .toc     section.
  the .toc section in powerpc64le modules are sometimes not aligned on a
    four     byte boundary. This fails the module linker especially when
    processing     R_PPC64_TOC16_LO_DS, since the addresses are expected
    to be aligned on 4byte     boundary.
  all parameter to firmware calls should to be BigEndian and the results
    should be CPU endian.
  grub segfaults if initrd is specified before specifying the kernel.
    The problem is the initrd module sees that kernel is not specified
    and takes the fail path. In the fail path it checks if anything
    has     be malloc'ed. Unfortunately the variable that it looks to
    check for     is a uninitialized stack variable. The stack variable
    can incorrectly     indicate something is malloced, which leads the
    module to free some     unallocated memory. This patch fixes the
    problem by initializing the     stack variable.
  Power7 cannot handle VSX instructions correctly. It segfaults.
    This patch is applicable only for power7 systems.
  Thomas Falcon (1):
  Add a new architecture to the build process
  Tomohiro B Berry (1):
  Add a new architecture to the build process
- added patches:
  * 0001-Add-a-new-architecture-to-the-build-process.patch
  * 0002-Build-grub-as-O1-until-we-add-savegpr-and-restgpr-ro.patch
  * 0003-powerpc64-LE-s-linker-knows-how-to-handle-the-undefi.patch
  * 0004-grub-install-can-now-recognize-and-install-a-LE-grub.patch
  * 0005-set-the-ABI-version-to-0x02-in-the-e_flag-of-the-PPC.patch
  * 0006-Add-IEEE1275_ADDR-helper.patch
  * 0007-Fix-some-more-warnings-when-casting.patch
  * 0008-Add-powerpc64-types.patch
  * 0009-Fix-warnings-when-building-powerpc-linux-loader-64bi.patch
  * 0010-GRUB_ELF_R_PPC_-processing-is-applicable-only-for-32.patch
  * 0011-Fix-powerpc-setjmp-longjmp-64bit-issues.patch
  * 0012-Add-powerpc64-ieee1275-trampoline.patch
  * 0013-Add-64bit-support-to-powerpc-startup-code.patch
  * 0014-Add-grub_dl_find_section_addr.patch
  * 0015-Add-ppc64-relocations.patch
  * 0016-ppc64-doesn-t-need-libgcc-routines.patch
  * 0017-Use-FUNC_START-FUNC_END-for-powerpc-function-definit.patch
  * 0018-.TOC.-symbol-is-special-in-ppc64le-.-It-maps-to-the-.patch
  * 0019-the-.toc-section-in-powerpc64le-modules-are-sometime.patch
  * 0020-all-parameter-to-firmware-calls-should-to-be-BigEndi.patch
  * 0021-powerpc64-is-not-necessarily-BigEndian-anymore.patch
  * 0022-grub-segfaults-if-initrd-is-specified-before-specify.patch
  * 0023-Power7-cannot-handle-VSX-instructions-correctly.-It-.patch
- removed patches:
  * grub2-powerpc-libgcc.patch
  * grub2-ppc64le-core-bigendian.patch
  * grub2-ppc64le-platform.patch
* Thu Feb 27 2014 jjolly@suse.com
- kexec performed as linux/initrd/boot under emu environment
* Thu Feb 27 2014 mchang@suse.com
- grub2-snapper-plugin: fix important snapshots are not marked as such
  in grub2 menu, also display the snapshot entries in the format
  "important distribution version (kernel_version, timestamp, pre/post)"
  (bnc#864842)
* Tue Feb 25 2014 jjolly@suse.com
- Fixed output on s390 3270 terminal. Strictly serial on s390 now
- kexec command added for emu platform
* Mon Feb 24 2014 mchang@suse.com
- refresh grub2-fix-menu-in-xen-host-server.patch (bnc#859361)
  * prevent 10_linux from booting xen kernel without pv_opt support
    on systems other than xen PV domU guest
  * prevent 20_linux_xen.in from setting up nested virt running from
    Xen domU
- refresh grub2-fix-Grub2-with-SUSE-Xen-package-install.patch
  * adjust accordingly
* Thu Feb 20 2014 jw@suse.com
- updating grub2-once
  - added --list switch.
  - improved --help and error handling.
* Tue Feb 11 2014 mchang@suse.com
- add Supplements: packageand(snapper:grub2) in grub2-snapper-plugin
  to install it while both snapper and grub2 are installed
* Wed Feb  5 2014 mchang@suse.com
- add grub2-snapper-plugin.sh (fate#316232)
  * grub2's snapper plugin for advanced btrfs snapshot menu management
  * package as grub2-snapper-plugin.noarch
- refresh 0002-script-create-menus-for-btrfs-snapshot.patch
  * when booting btrfs snapshots disabled, deleting snapshot master config
    if it's not customized
* Fri Jan 31 2014 dvaleev@suse.com
- Enable grub2 for PowerPC LE (ppc64le)
- Add ppc64le to exclusive arches
- Don't require gcc-32bit (PowerLE don't have 32bit toolchain)
- added patches:
  * grub2-powerpc-libgcc.patch
    Provide 32bit libgcc functions for PowerLE
  * grub2-ppc64le-core-bigendian.patch
    Build grub kernel and images as BE on ppc64le (BL is BE there)
  * grub2-ppc64le-platform.patch
    Enable ppc64le platform
* Fri Jan 24 2014 jjolly@suse.com
- Add changes to allow build for s390x arch: added
  grub2-s390x-01-Changes-made-and-files-added-in-order-to-allow-s390x.patch
* Wed Jan 22 2014 mchang@suse.com
- refresh 0002-script-create-menus-for-btrfs-snapshot.patch
  * Fix bootable snapshots not found while root is on Btrfs subvolume
  (bnc#859587)
  * Create missing slave config in /.snapshots/<num>/
  * Prefix with SUSE_ for related options
* Fri Jan 17 2014 mchang@suse.com
- refresh 0001-script-provide-overridable-root-by-subvol.patch
  * Introduce $boot_prefix for setting prefix on seeking other /boot
  directory.
- refresh 0002-script-create-menus-for-btrfs-snapshot.patch
  * Support existing snapshots by creating their missing slave configs.
  * Temporarily default to disable this feature until receiving more
  tests from QA.
  * Introduce GRUB_ENABLE_CUSTOM_SNAPSHOT_SUBMENU to allow custom
  submenu for listing snapshots rather than the default one.
* Wed Jan 15 2014 arvidjaar@gmail.com
- package autoiso.cfg and osdetect.cfg as documentation
- add 0001-look-for-DejaVu-also-in-usr-share-fonts-truetype.patch -
  fix configure test for DejaVu font
- add dejavu-fonts to BR (needed to build starfield theme)
- package starfield theme as grub2-branding-upstream
- add grub2-use-DejaVuSansMono-for-starfield-theme.patch - use fixed width
  font for starfield theme
- clarify that grub2 subpackage contains only user space tools
* Wed Jan 15 2014 mchang@suse.com
- add new patches for booting btrfs snapshot (fate#316522) (fate#316232)
  * 0001-script-provide-overridable-root-by-subvol.patch
  * 0002-script-create-menus-for-btrfs-snapshot.patch
* Fri Dec 27 2013 arvidjaar@gmail.com
- update to grub-2.02 beta2
  * drop upstream patches
  - grub2-fix-unquoted-string-in-class.patch (different)
  - grub2-cdpath.patch (modified)
  - grub2-fix-parsing-of-short-LVM-PV-names.patch
  - grub2-fix-descriptor-leak-in-grub_util_is_imsm.patch
  - grub2-install-opt-skip-fs-probe.patch (file it patched no more exists,
    functionality included upstream)
  - grub2-fix-x86_64-efi-startup-stack-alignment.patch
  - grub2-fix-x86_64-efi-callwrap-stack-alignment.patch
  - 0001-Fix-build-with-FreeType-2.5.1.patch
  * rediff
  - grub2-linux.patch
  - use-grub2-as-a-package-name.patch (do not patch generated configure)
  - grub2-GRUB_CMDLINE_LINUX_RECOVERY-for-recovery-mode.patch
  - grub2-fix-locale-en.mo.gz-not-found-error-message.patch (upstream added
    explicit exclusion for en_* language only; I do not see reason to stop
    with error in this case for any language).
  - not-display-menu-when-boot-once.patch
  - grub2-secureboot-provide-linuxefi-config.patch
  - grub2-pass-corret-root-for-nfsroot.patch
  - 0002-btrfs-add-ability-to-boot-from-subvolumes.patch
  - grub2-fix-menu-in-xen-host-server.patch
  - grub2-fix-Grub2-with-SUSE-Xen-package-install.patch
  - grub2-secureboot-add-linuxefi.patch
  - grub2-secureboot-no-insmod-on-sb.patch
  - rename-grub-info-file-to-grub2.patch
  * drop Makefile.util.am and Makefile.core.am, they are now generated
    during build
  * call ./autogen.sh again now when it does not need autogen anymore; drop
    autoreconf call, it is called by autogen.sh
  * drop 0001-btrfs-rename-skip_default-to-follow_default.patch - is not
    needed anymore due to upstream changes
  * package /usr/bin/grub2-file, /usr/bin/grub2-syslinux2cfg and
    /usr/sbin/grub2-macbless
  * use grub-install --no-bootsector instead of --grub-setup=/bin/true
    in postinstall script
* Tue Dec 17 2013 mchang@suse.com
- add new patches for booting btrfs snapshot (fate#316522) (fate#316232)
  * 0001-btrfs-rename-skip_default-to-follow_default.patch
  * 0002-btrfs-add-ability-to-boot-from-subvolumes.patch
  * 0003-cmdline-add-envvar-loader_cmdline_append.patch
  * 0004-btrfs-export-subvolume-envvars.patch
* Tue Dec 10 2013 arvidjaar@gmail.com
- add patch 0001-Fix-build-with-FreeType-2.5.1.patch - fix build with
  freetype2 >= 2.5.1 (backport from fd0df6d098b1e6a4f60275c48a3ec88d15ba1fbb)
* Sun Dec  1 2013 arvidjaar@gmail.com
- reset executable bits on *module, *.exec and *.image files. They are not
  executable.
* Fri Nov 22 2013 glin@suse.com
- add grub2-fix-x86_64-efi-startup-stack-alignment.patch and
  grub2-fix-x86_64-efi-callwrap-stack-alignment.patch: fix the
  stack alignment of x86_64 efi. (bnc#841426)
* Wed Sep 11 2013 mchang@suse.com
- use new update-bootloader option --reinit to install and update
  bootloader config
- refresh grub2-secureboot-no-insmod-on-sb.patch to fobid module
  loading completely.
* Mon Sep  9 2013 lnussel@suse.de
- replace openSUSE UEFI certificate with new 2048 bit certificate.
* Sat Jul 27 2013 arvidjaar@gmail.com
- add grub2-fix-parsing-of-short-LVM-PV-names.patch - fix PV detection in
  grub-probe when PV name is less than 10 charaters
- add grub2-fix-descriptor-leak-in-grub_util_is_imsm.patch - fix decriptor
  leak which later caused LVM warnings during grub-probe invocation
- remove --enable-grub-emu-usb - it is not needed on physical platform
* Tue Jul  9 2013 mchang@suse.com
- refresh grub2-fix-menu-in-xen-host-server.patch: In domU we
  have to add xen kernel to config. (bnc#825528)
* Wed Jun 26 2013 elchevive@opensuse.org
- updated existent translations and include new ones
  (es, lt, pt_BR, sl, tr)
* Sun Jun 16 2013 arvidjaar@gmail.com
- update to current upstream trunk rev 5042
  * drop upstream patches
  - grub2-correct-font-path.patch
  - grub2-fix-mo-not-copied-to-grubdir-locale.patch
  - grub2-stdio.in.patch
  - grub2-fix-build-error-on-flex-2.5.37.patch
  - grub2-quote-messages-in-grub.cfg.patch
  - 30_os-prober_UEFI_support.patch
  - grub2-fix-enumeration-of-extended-partition.patch
  - grub2-add-device-to-os_prober-linux-menuentry.patch
  - grub2-fix-tftp-endianness.patch
  - efidisk-ahci-workaround
  - grub2-grub-mount-return-failure-if-FUSE-failed.patch
  * rediff
  - rename-grub-info-file-to-grub2.patch
  - grub2-linux.patch
  - use-grub2-as-a-package-name.patch
  - grub2-iterate-and-hook-for-extended-partition.patch
  - grub2-secureboot-add-linuxefi.patch
  - grub2-secureboot-no-insmod-on-sb.patch
  - grub2-secureboot-chainloader.patch
  * add
  - grub2-linguas.sh-no-rsync.patch
    + disable rsync in linguas.sh so it can be used during RPM build
    + disable auto-generated catalogs, they fail at the moment due to
    missing C.UTF-8 locale
  * update Makefile.util.am and Makefile.core.am
  * grub2-mknetdir is now in /usr/bin
  * generate po/LINGUAS for message catalogs using distributed linguas.sh
  * remove po/stamp-po during setup to trigger message catalogs rebuild
  * package bootinfo.txt on PPC (used by grub2-mkrescue)
* Sat Apr 13 2013 arvidjaar@gmail.com
- BuildRequires: help2man to generate man pages and package them too
* Fri Apr  5 2013 arvidjaar@gmail.com
- add grub2-secureboot-use-linuxefi-on-uefi-in-os-prober.patch (bnc#810912)
  * use linuxefi in 30_os-prober if secure boot is enabled
* Wed Apr  3 2013 arvidjaar@gmail.com
- update rename-grub-info-file-to-grub2.patch
  * do not rename docs/grub2.texi here, do it in %%%%prep (we do it there
    conditionally already). It simplifies patch refreshing using quilt
    which does not support file rename.
* Wed Apr  3 2013 mchang@suse.com
- refresh grub2-secureboot-chainloader.patch: Fix wrongly aligned
  buffer address (bnc#811608)
* Thu Mar 28 2013 mchang@suse.com
- package Secure Boot CA file as /usr/lib64/efi/grub.der which
  could be used to verify signed image from build server
- add openSUSE-UEFI-CA-Certificate.crt, openSUSE Secure Boot CA
- add SLES-UEFI-CA-Certificate.crt, SUSE Linux Enterprise Secure
  Boot CA
* Mon Mar 25 2013 dvaleev@suse.com
- extraconfigure macro is not defined on ppc
* Sat Mar 23 2013 arvidjaar@gmail.com
- corretly set chainloaded image device handle in secure boot mode (bnc#809038)
* Wed Mar 13 2013 mchang@suse.com
- remove all compatible links in grub2-efi as now all concerned
  utilities are fixed
- superseding grub2-efi by grub2-x86_64-efi and grub2-i386-efi on
  x86_64 and ix86 respectively
- make grub2-x86_64-efi and grub2-i386-efi providing grub2-efi
  capability to not break package dependency
- handle upgrade from 12.2 by preseving grubenv and custom.cfg to
  new directory /boot/grub2, rename /boot/grub2-efi to
  /boot/grub2-efi.rpmsave to avoid confusion.
* Mon Mar 11 2013 arvidjaar@gmail.com
- move post scripts into corresponding subpackages to ensure they are
  run after updated binaries are installed. Currently it may happen
  that update-bootlader picks up old binaries.
- move requires for perl-Bootloader to target subpackages. Make sure
  efi requires minimal version that supports /boot/grub2.
- add requires(post) to force order of installation: grub2 => grub2-arch
  => grub2-efi
- split efi post in two parts. One that updates configuration and is part
  of grub2-efiarch and second that migrates settings and is part of
  grub2-efi. Only custom.cfg and grubenv may need migration. device.map
  is not relevant for EFI and new grub.cfg had been created at this point.
* Mon Mar 11 2013 mchang@suse.com
- add grub2-fix-tftp-endianness.patch from upstream (bnc#808582)
- add efinet and tftp to grub.efi (bnc#808582)
* Thu Mar  7 2013 seife+obs@b1-systems.com
- convert spec file to UTF-8
* Thu Mar  7 2013 mchang@suse.com
- add lvm to grub.efi (bnc#807989)
- add loadenv to grub.efi (bnc#807992)
* Mon Mar  4 2013 arvidjaar@gmail.com
- grub2-grub-mount-return-failure-if-FUSE-failed.patch - return error
  if fuse_main failed (bnc#802983)
* Mon Feb 25 2013 fcrozat@suse.com
- Fix build for SLES 11.
* Tue Feb 19 2013 duwe@suse.com
  Fix up bogus items from the previous merge:
  - efi_libdir = _libdir = /usr/lib
  - package /usr/lib/grub2 dir only once
  - move grub.efi to /usr/lib/grub2/%%{grubefiarch}/
  - create a symlink so that scripts can find it there.
* Thu Feb 14 2013 duwe@suse.com
- merge internal+external BS changes into superset spec file,
  remove obsolete dependencies
- merge SLES+openSUSE patches, restrict "grub-efi" to 12.2
- add efidisk-ahci-workaround (bnc#794674)
- fix unquoted-string-in-class.patch (bnc#788322)
* Fri Feb  8 2013 mchang@suse.com
- adapt to pesign-obs-integration changes
* Thu Feb  7 2013 mchang@suse.com
- grub.efi signing on build server.
* Thu Jan 31 2013 duwe@suse.com
- switch to out of source / subdir build
* Wed Jan 30 2013 mchang@suse.com
- sync from SLE-11 SP3 to date
- set empty prefix to grub.efi for looking up in current directory
- grub2-cdpath.patch: fix the grub.cfg not found when booting from
  optical disk
- put grub.efi in grub2's source module directory
- create links in system's efi directory to grub.efi
- arvidjaar: do not overwrite device path in grub2-cdpath.patch
* Wed Jan 30 2013 arvidjaar@gmail.com
- remove obsolete reference to /boot/grub2-efi and /usr/sbin/grub2-efi
  from grub2-once
- add GRUB_SAVEDFAULT description to /etc/default/grub
* Tue Jan 29 2013 mchang@suse.com
- set empty prefix to grub.efi for looking up in current directory
- remove grubcd.efi, as grub.efi can now be used for cdrom booting
* Mon Jan 28 2013 snwint@suse.de
- add fat module to grubcd
- explicitly set empty prefix to get grub to set $prefix to the currrent
  directory
* Fri Jan 18 2013 mchang@suse.com
- ship a Secure Boot UEFI compatible bootloader (fate#314485)
- add grub2-secureboot-chainloader.patch, which expands the efi
  chainloader to be able to verify images via shim lock protocol.
* Fri Jan 18 2013 mchang@suse.com
- ship a Secure Boot UEFI compatible bootloader (fate#314485).
- update for cdrom boot support.
- grub2-cdpath.patch: fix the grub.cfg not found when booting from
  optical disk.
- grubcd.efi: the efi image used for optial disk booting, with
  reduced size and $prefix set to /EFI/BOOT.
* Tue Jan  8 2013 mchang@suse.com
- add grub2-fix-unquoted-string-in-class.patch (bnc#788322)
* Tue Jan  8 2013 arvidjaar@gmail.com
- add grub2-add-device-to-os_prober-linux-menuentry.patch (bnc#796919)
* Sun Jan  6 2013 arvidjaar@gmail.com
- add patch grub2-fix-enumeration-of-extended-partition.patch to
  fix enumeration of extended partitions with non-standard EBR (bnc#779534)
* Fri Jan  4 2013 arvidjaar@gmail.com
- add support for chainloading another UEFI bootloader to
  30_os-prober (bnc#775610)
* Fri Dec 21 2012 mchang@suse.com
- put 32-bit grub2 modules to /usr/lib/grub2
- put 64-bit grub2 modules to /usr/lib64/grub2 (x86_64-efi)
- put grub.efi to /usr/lib64/efi(x86_64) or /usr/lib/efi(i586)
* Tue Dec 18 2012 mchang@suse.com
- ship a Secure Boot UEFI compatible bootloader (fate#314485)
- add grub2-secureboot-chainloader.patch, which expands the efi
  chainloader to be able to verify images via shim lock protocol.
* Fri Nov 30 2012 mchang@suse.com
- replace %%{sles_version} by %%{suse_version}
- use correct product name
* Mon Nov 26 2012 mchang@suse.com
- ship a Secure Boot UEFI compatible bootloader (fate#314485)
- added secureboot patches which introduces new linuxefi module
  that is able to perform verifying signed images via exported
  protocol from shim. The insmod command will not function if
  secure boot enabled (as all modules should built in grub.efi
  and signed).
  - grub2-secureboot-add-linuxefi.patch
  - grub2-secureboot-use-linuxefi-on-uefi.patch
  - grub2-secureboot-no-insmod-on-sb.patch
  - grub2-secureboot-provide-linuxefi-config.patch
- Makefile.core.am : support building linuxefi module
- Make grub.efi image that is with all relevant modules incorporated
  and signed, it will be the second stage to the shim loader which
  will verified it when secureboot enabled.
- Make grub.efi's path to align with shim loader's default loader
  lookup path.
- The changes has been verified not affecting any factory instalation,
  but will allow us to run & test secure boot setup manually with shim.
* Thu Nov 22 2012 mchang@suse.com
- ship a Secure Boot UEFI compatible bootloader (fate#314485)
- In SLE-11 SP3, don't include any other architecture binaries
  except EFI, so we split packages by architecture binaries to
  meet the requirement.
  - grub2 : common utilties and config etc
  - grub2-efi : provide compatibilty to grub2-efi package
  - grub2-i386-pc : binaries for x86 legacy pc firmware
  - grub2-i386-efi : binaries for ia32 EFI firmware
  - grub2-x86_64-efi : binaries for x86_64 firmware
  - grub2-powerpc-ieee1275: binaries for powerpc open firmware
* Tue Nov 20 2012 arvidjaar@gmail.com
- update grub2-quote-messages-in-grub.cfg.patch to use upstream commit
* Mon Nov 19 2012 arvidjaar@gmail.com
- quote localized "Loading ..." messages in grub.cfg (bnc#790195)
* Mon Nov  5 2012 aj@suse.de
- We really only need makeinfo, so require that one where it exists.
* Thu Nov  1 2012 mchang@suse.com
- ship a Secure Boot UEFI compatible bootloader (fate#314485)
- Secure boot support in installer DVD (fate#314489)
- prime support for package on SLE-11 (SP3)
  - remove buildrequire to libuse and ncurses 32-bit devel packages
    as they are needed by grub-emu which we don't support
  - remove buildrequire to freetype2-devel-32bit as it's not need
    by grub2-mkfont and others
  - buildrequire to xz instead of lzma
  - buildrequire to texinfo instead of makeinfo
  - remove buildrequire to autogen as it's not available in SLE-11
  - add Makefile.util.am Makefile.core.am generated by autogen
  - run autoreconf -vi instead of ./autogen.sh
  - For SLE-11 remove buildrequire to gnu-unifont as it's not
    yet available. Also do not package pf fonts created from it.
  - workaround SLE-11 patch utility not rename file for us
  - add -fno-inline-functions-called-once to CFLAGS to fix build
    error on gcc 4.3.x
  - not require os-prober for SLE-11, as package not yet ready
* Sat Oct 27 2012 arvidjaar@gmail.com
- grub2-efi now depends on exact grub2 version
* Thu Oct 25 2012 arvidjaar@gmail.com
- build grub2-efi with standard "grub2" prefix (bnc#782891)
  - remove use-grub2-efi-as-a-package-name.patch
  - migrate settings from /boot/grub2-efi to /boot/grub2 in efi post
  - provide some compatibility links grub2-efi-xxx for perl-Bootloader
  - workaround for /boot/grub2-efi linkk and /boot/grub2/grub.cfg
    missing on update from older versions
* Thu Oct 25 2012 mchang@suse.com
- add grub2-fix-build-error-on-flex-2.5.37.patch
* Thu Oct 18 2012 arvidjaar@gmail.com
- modify patch grub2-iterate-and-hook-for-extended-partition.patch to
  ignore extended partitions other then primary (bnc#785341)
* Wed Sep 26 2012 mchang@suse.com
- refresh grub2-fix-locale-en.mo.gz-not-found-error-message.patch
  with the correct fix in upstream bugzilla #35880 by Colin Watson
  (bnc#771393)
* Fri Sep 21 2012 mchang@suse.com
- grub2-fix-locale-en.mo.gz-not-found-error-message.patch (bnc#771393)
* Wed Sep 19 2012 arvidjaar@gmail.com
- add 20_memtest86+ (bnc#780622)
* Tue Sep 18 2012 mchang@suse.com
- Fix un-bootable grub2 testing entry in grub's menu.lst (bnc#779370)
- Not add new grub2 testing entry if it's not found in menu.lst
- Update grub2 stuff and config if there's grub2 entry in menu.lst
- Check for current bootloader as update-bootloader acts on it
* Thu Aug 30 2012 mchang@suse.com
- add grub2-fix-Grub2-with-SUSE-Xen-package-install.patch (bnc#774666)
- add grub2-pass-corret-root-for-nfsroot.patch (bnc#774548)
* Mon Aug 20 2012 mchang@suse.com
- disable grub2-enable-theme-for-terminal-window.patch to use
  default black background due to current background has poor
  contrast to the font color (bnc#776244).
* Fri Aug 10 2012 jslaby@suse.de
- rename grub2once to grub2-once
* Wed Aug  1 2012 mchang@suse.com
- add grub2once (bnc#771587)
- add not-display-menu-when-boot-once.patch
* Sat Jul 28 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Fri Jul 27 2012 tittiatcoke@gmail.com
- Add grub2-enable-theme-for-terminal-window.patch (bnc#770107)
* Thu Jul 19 2012 mchang@suse.com
- add grub2-fix-menu-in-xen-host-server.patch (bnc#757895)
* Wed Jul 18 2012 mchang@suse.com
- add grub2-fix-error-terminal-gfxterm-isn-t-found.patch
- add grub2-fix-mo-not-copied-to-grubdir-locale.patch
* Wed Jul 18 2012 aj@suse.de
- We only need makeinfo, not texinfo for building.
* Tue Jul 17 2012 jslaby@suse.de
- fix build by adding texinfo to buildrequires.
* Fri Jul  6 2012 mchang@suse.com
- grub2-GRUB_CMDLINE_LINUX_RECOVERY-for-recovery-mode.patch. We
  don't run in sigle user mode for recovery, instead use different
  set kernel command line options which could be specified by this
  GRUB_CMDLINE_LINUX_RECOVERY setting.
* Wed Jul  4 2012 mchang@suse.com
- add use-grub2-efi-as-a-package-name.patch (bnc#769916)
* Fri Jun 29 2012 dvaleev@suse.com
- Add configuration support for serial terminal consoles. This will
  set the maximum screen size so that text is not overwritten.
* Fri Jun 29 2012 dvaleev@suse.com
- don't enable grub-emu-usb on ppc ppc641
* Thu Jun 28 2012 jslaby@suse.de
- update to 2.0 final
  * see ChangeLog for changes
* Mon Jun 25 2012 adrian@suse.de
- enable xz/lzma support for image file generation
* Sun Jun 24 2012 jslaby@suse.de
- update to 2.0 beta6, a snapshot from today
  * see ChangeLog for changes
* Fri Jun 22 2012 mchang@suse.com
- do not package grub.cfg, as it's generated at runtime and the
  presence of it would confuse pygrub (bnc#768063)
* Wed May 16 2012 mchang@suse.com
- fix build error on 12.1 caused by autogen aborts because of
  absence of guile package
* Wed May  2 2012 mchang@suse.com
- grub2-automake-1-11-2.patch : fix grub2 build error on newer
  autotools (automake >= 1.11.2)
- call ./autogen.sh
* Thu Apr 19 2012 mchang@suse.com
- grub2-probe-disk-mountby.patch : fix grub2-probe fails on
  probing mount-by devices under /dev/disk/by-(id|uuid|path).
  (bnc#757746)
* Thu Mar 29 2012 mchang@suse.com
- Add Requires to os-prober as script depends on it for probing
  foreign os (bnc#753229)
* Wed Mar 21 2012 mchang@suse.com
- Mark %%config(noreplace) to /etc/default/grub (bnc#753246)
* Fri Mar 16 2012 aj@suse.de
- Fix build with gcc 4.7 (needs -fno-strict-aliasing for zfs code).
* Tue Mar 13 2012 mchang@suse.com
- Fix error in installation to extended partition (bnc#750897)
  add grub2-iterate-and-hook-for-extended-partition.patch
  add grub2-install-opt-skip-fs-probe.patch
* Mon Mar 12 2012 tittiatcoke@gmail.com
- Added BuildRequires for gnu-unifont in order to create the
  necessary fonts for a graphical boot menu.
* Mon Feb 20 2012 andrea.turrini@gmail.com
- fixed typos in grub2.spec
* Mon Jan  2 2012 mchang@suse.com
- platforms without efi should not specify exclusion of it
* Thu Dec 29 2011 mchang@suse.com
- set --target=%%{_target_plaform) explicitly to %%configure in case
  it wouldn't do that for us implicitly
- when making x86_64-efi image not use i386 target build and keep
  use of x86_64. otherwise it would have error "invalid ELF header"
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Nov 28 2011 jslaby@suse.de
- remove doubly packaged files
- remove INSTALL from docs
- handle duplicate bindir files
* Mon Oct 31 2011 meissner@suse.de
- make efi exclusion more complete
* Thu Oct 27 2011 aj@suse.de
- efibootmgr only exists on x86-64 and ia64.
* Tue Oct 25 2011 aj@suse.de
- Add requires from efi subpackage to main package (bnc#72596)
* Mon Oct 24 2011 jslaby@suse.de
- update it and pl translations
- cleanup spec file
  * don't package efi files to non-efi package
* Thu Aug 25 2011 aj@suse.de
- Fix directory ownership.
* Tue Aug 23 2011 aj@suse.de
- Build an efi subpackage [bnc#713595].
* Tue Aug  2 2011 dvaleev@novell.com
- enable ppc build
- patch unused-but-set-variable
* Tue Jul 12 2011 aj@suse.de
- Create submenu for all besides primary Linux kernels.
- Only run preun section during package install but not during
  upgrade.
* Tue Jul 12 2011 aj@suse.de
- Update README.openSUSE
* Tue May 31 2011 jslaby@suse.de
- update translations
- update to 1.99 final
  * See NEWS file for changes
* Sat May  7 2011 jslaby@suse.de
- fix build with gcc 4.6
- build in parallel (fixed finally in 1.99)
- add translations from translations project
- update to 1.99-rc2
  * See NEWS file for changes
* Wed Oct 27 2010 jslaby@suse.de
- fix vanishing of /boot/grub2/* if /boot/grub/device.map
  doesn't exist
* Mon Oct 25 2010 jslaby@suse.de
- add missing " in the default file; add "fi" to grub2-linux.patch
* Mon Oct 11 2010 jslaby@suse.de
- repack gz to bz2 (0.5M saving)
* Sat Oct  9 2010 aj@suse.de
- Do not output vmlinux if vmlinuz of same version exists.
- Update default grub file.
* Sat Oct  9 2010 aj@suse.de
- Add patch grub-1.98-follow-dev-mapper-symlinks.patch from Fedora
  for grub2-probe to detect lvm devices correctly
* Sat Sep 11 2010 jslaby@suse.de
- add gettext "requires"
* Sun Mar 14 2010 aj@suse.de
- Fix build on x86-64.
* Fri Mar 12 2010 aj@suse.de
- Don't build parallel.
- Update to grub 1.98 including:
  * Multiboot on EFI support.
  * Saved default menu entry support, with new utilities `grub-reboot' and
    `grub-set-default'.
  * Encrypted password support, with a new utility `grub-mkpasswd-pbkdf2'.
  * `grub-mkfloppy' removed; use `grub-mkrescue' to create floppy images.
* Fri Feb 12 2010 aj@suse.de
- Update to grub 1.97.2:
  * Fix a few 4 GiB limits.
  * Fix license problems with a few BSD headers.
  * Lots of misc bugfixes.
* Wed Dec  9 2009 aj@suse.de
- Fix requires.
* Wed Dec  9 2009 aj@suse.de
- Mark /etc/default/grub as config file.
* Wed Dec  9 2009 aj@suse.de
- Mark root partition rw
* Wed Dec  9 2009 aj@suse.de
- New package grub2.
